#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

import pkgutil

import sys
import os
import gc
import urllib.error
import googleapiclient.errors

import datetime
import time
import pickle

import process_entry
from locks import acquire_lock

if len(sys.argv) > 1:
    names = sys.argv[1:]
else:
    names = None

entries = process_entry.get_entries(names).values()

process_entry._check_health = True

for entry in entries:
    if entry.orphan:
        print("skipped orphan:", entry.name)
        continue
    with acquire_lock(entry, block=False) as lock:
        if lock is None:
            continue

        print("check upstream health,", entry.name, end=": ")

        status = 200
        date = 0

        hfile = f"./cache/upstream/{entry.name}/.health"
        try:
            with open(hfile, "rb") as f:
                status, date = pickle.load(f)
        except (FileNotFoundError, IOError, EOFError):
            pass
        if time.time() - date > 24 * 60 * 60:
            try:
                entry.fetch_upstream(force=True)
                status = 200
            except googleapiclient.errors.HttpError as e:
                status = e.resp.status
            except urllib.error.HTTPError as e:
                status = e.code
            except urllib.error.URLError as e:
                status = e.reason
            date = time.time()

        with open(hfile, "wb") as f:
            pickle.dump((status, date), f)

        print(status, date)