#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

import pkgutil

import sys
import os
import gc
import numpy.random

import graph_tool

from process_entry import *
from analyze import *
from update_props import *
from draw import *
from get_bibtex import *

from locks import acquire_lock

if len(sys.argv) > 1:
    names = sys.argv[1:]
else:
    names = None

entries = list(process_entry.get_entries(names).values())

if len(sys.argv) == 1:
    analyze_entries(entries, names=["num_vertices"])
    f = lambda x: x if x is not None else 0
    entries = sorted(entries, key=lambda e: f(e._analyses.get("num_vertices", 0)))

for entry in entries:
    with acquire_lock(entry, block=False) as lock:
        if lock is None:
            continue
        print("entry:", entry.name)
        print("\tfetching...")
        entry.fetch_upstream()
        print("\tparsing...")
        for alt, g in entry.parse(lazy=True):
            print("\tparsed:", alt)
        print("\tanalysing...")

        analyze_entries([entry], cache_only=False)

        updated = False
        for alt, g in update_props(entry, ret_all=False):
            print("\tconverting (w/ updated props)...")
            convert_entry(entry, alts=[alt], force=True)
            updated = True

        if updated:
            analyze_entries([entry], cache_only=False,
                            force=["vertex_properties",
                                   "edge_properties"])

        print("\tdrawing...")
        for alt, g in entry.parse(cache_only=True, lazy=True):
            print(f"\t {alt}...")
            draw_entry(entry, alt, thumb=True)

        print("\tconverting...")
        convert_entry(entry)

        print("\tgenerating bibtex...")
        bibtex_entry(entry)
