#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Amazon co-purchasing network (2003)"
description = """Network of items for sale on amazon.com in 2003 and the items they \"recommend\" (via the \"Customers Who Bought This Item Also Bought\" feature). If one item is frequently co-purchased with another, then the first item recommends the second.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Economic', 'Commerce', 'Unweighted']
url = 'http://snap.stanford.edu/data/amazon0302.html'
citation = [('J. Leskovec, L. Adamic and B. Adamic. "The Dynamics of Viral Marketing." ACM Transactions on the Web (ACM TWEB), 1 (2007)', 'https://doi.org/10.1145/1232722.1232727')]
icon_hash = '56a85c8e26855e083a2f78bb'
ustream_license = None
upstream_prefix = 'https://snap.stanford.edu/data'
files = [('amazon0302.txt.gz', '302', 'snap'),
         ('amazon0312.txt.gz', '312', 'snap'),
         ('amazon0505.txt.gz', '505', 'snap'),
         ('amazon0601.txt.gz', '601', 'snap')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=True)
        yield alt, g
