#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Philippines Ambassador bombing (2000)"
description = """A temporal network representing snapshots of relationships among individuals directly or indirectly associated with Philippines Ambassador Residence Bombing 2000, Jakarta. Nodes are people, and an edge exists if they are associated with each other. Definition of the edge weight is unknown.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Offline', 'Weighted', 'Temporal']
url = 'https://sites.google.com/site/ucinetsoftware/datasets/covert-networks/philippinesbombing'
citation = [('S. Atran et al., "Philippines Ambassador Residence Bombing 2000, Jakarta." John Jay & ARTIS Transnational Terrorism Database (2009)', 'http://doitapps.jjay.cuny.edu/jjatt/data.php')]
icon_hash = '59fe8cadee01e9ab21ac7fb5'
upstream_prefix = 'https://sites.google.com/site/ucinetsoftware/datasets/covert-networks/philippinesbombing'
files = [('Philippines%20Bombing%202000%20CSV.zip:CSV/PHILBOMB_2000_1985_1989.csv', '1985_1989', 'csv_matrix'), ('Philippines%20Bombing%202000%20CSV.zip:CSV/PHILBOMB_2000_1990_1994.csv', '1990_1994', 'csv_matrix'), ('Philippines%20Bombing%202000%20CSV.zip:CSV/PHILBOMB_2000_1995_1999.csv', '1995_1999', 'csv_matrix'), ('Philippines%20Bombing%202000%20CSV.zip:CSV/PHILBOMB_2000_2000.csv', '2000', 'csv_matrix'), ('Philippines%20Bombing%202000%20CSV.zip:CSV/PHILBOMB_2000_2001.csv', '2001', 'csv_matrix'), ('Philippines%20Bombing%202000%20CSV.zip:CSV/PHILBOMB_2000_2002.csv', '2002', 'csv_matrix'), ('Philippines%20Bombing%202000%20CSV.zip:CSV/PHILBOMB_2000_2003.csv', '2003', 'csv_matrix'), ('Philippines%20Bombing%202000%20CSV.zip:CSV/PHILBOMB_2000_2004.csv', '2004', 'csv_matrix'), ('Philippines%20Bombing%202000%20CSV.zip:CSV/PHILBOMB_2000_2005.csv', '2005', 'csv_matrix'), ('Philippines%20Bombing%202000%20CSV.zip:CSV/PHILBOMB_2000_2006.csv', '2006', 'csv_matrix'), ('Philippines%20Bombing%202000%20CSV.zip:CSV/PHILBOMB_2000_2007.csv', '2007', 'csv_matrix'), ('Philippines%20Bombing%202000%20CSV.zip:CSV/PHILBOMB_2000_KINSHIP.csv', 'KINSHIP', 'csv_matrix'), ('Philippines%20Bombing%202000%20CSV.zip:CSV/PHILBOMB_2000_OPERATION_ID.csv', 'OPERATION_ID', 'csv_matrix'), ('Philippines%20Bombing%202000%20CSV.zip:CSV/PHILBOMB_2000_TIE_EXTINGUISH.csv', 'TIE_EXTINGUISH', 'csv_matrix'), ('Philippines%20Bombing%202000%20CSV.zip:CSV/PHILBOMB_2000_TIE_YEAR.csv', 'TIE_YEAR', 'csv_matrix')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=False)
        yield alt, g
