#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Arxiv authors (1993-2003)"
description = """Scientific collaborations between authors of papers submitted to arxiv.org, under 5 categories: gr-qc, astro-ph, cond-mat, hep-ph, and hep-th categories, spanning January 1993 to April 2003. If an author i co-authored a paper with author j, the graph contains a undirected edge from i to j. If the paper is co-authored by k authors this generates a completely connected (sub)graph on k nodes.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Collaboration', 'Unweighted', 'Projection']
url = 'http://snap.stanford.edu/data/ca-GrQc.html'
citation = [('Leskovec, J. Kleinberg and C. Faloutsos. "Graph Evolution: Densification and Shrinking Diameters." ACM Transactions on Knowledge Discovery from Data 1(1), article 2 (2007).', 'https://doi.org/10.1145/1217299.1217301')]
icon_hash = '56a85c8e26855e083a2f78b9'
ustream_license = None
upstream_prefix = 'http://snap.stanford.edu/data'
files = [(f'ca-{d}.txt.gz', f'{d}', 'snap') for d in ['AstroPh','CondMat','GrQc', 'HepPh', 'HepTh']]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=False)
        yield alt, g
