#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Scientific collaborations in physics (1995-2005)"
description = """Collaboration graphs for scientists, extracted from the Los Alamos e-Print arXiv (physics), for 1995-1999 for three categories, and additionally for 1995-2003 and 1995-2005 for one category. For copyright reasons, the MEDLINE (biomedical research) and NCSTRL (computer science) collaboration graphs from this paper are not publicly available.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Collaboration', 'Weighted', 'Projection']
url = 'http://www-personal.umich.edu/~mejn/netdata/'
citation = [('M. E. J. Newman, "The structure of scientific collaboration networks." Proc. Natl. Acad. Sci. USA 98(2), 404-409 (2001). arxiv:cond-mat/0007214', 'https://doi.org/10.1073/pnas.98.2.404')]
icon_hash = '56a85c8e26855e083a2f78a8'
ustream_license = None
upstream_prefix = 'http://www-personal.umich.edu/~mejn/netdata/'
files = [("cond-mat.zip:cond-mat.gml", "cond-mat-1999", "gml"),
         ("cond-mat-2003.zip:cond-mat-2003.gml", "cond-mat-2003", "gml"),
         ("cond-mat-2005.zip:cond-mat-2005.gml", "cond-mat-2005", "gml"),
         ("astro-ph.zip:astro-ph.gml", "astro-ph-1999", "gml"),
         ("hep-th.zip:hep-th.gml", "hep-th-1999", "gml")]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=False)
        yield alt, g
