#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Chinese online encyclopedias (2011)"
description = """Four networks from Chinese online encyclopedias Baidu (百度百科, http://baike.baidu.com/) and Hudong (互动百科, http://www.hudong.com/). Edge direction indicates that page i hyperlinks to page j. Networks come with two types: \"internal\" and \"related to.\" The former networks are direct hyperlinks between articles, while the latter are \"related to\" links between articles.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Informational', 'Web graph', 'Unweighted']
url = 'http://konect.cc/networks/zhishi-baidu-internallink'
citation = [('X. Niu et al., "Zhishi.me -- weaving Chinese linking open data." Proc. Internat. Semantic Web Conf. (2011).', 'https://doi.org/10.1007/978-3-642-25093-4_14')]
icon_hash = '57eadd1e8cf714f319c38e44'
upstream_prefix = 'http://konect.cc/files'
files = [('download.tsv.zhishi-baidu-internallink.tar.bz2', None, 'konect')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=True)
        yield alt, g
