#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Baseball steroid use (2008)"
description = """Two networks representing steroid use among baseball players. First, a bipartite network of players and their steroid providers (of illegal performance-enhancing substances). Second, a one-mode projection of players, which are linked if they have a common supplier.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Offline', 'Weighted', 'Projection']
url = 'http://orgnet.com/steroids.html'
citation = [('V. Krebs, "The Spread of Steroids in Baseball."', 'http://orgnet.com/steroids.html')]
icon_hash = '59daeba7ee01e9ab21aadc6f'
upstream_prefix = 'https://28915467-a-62cb3a1a-s-sites.googlegroups.com/site/ucinetsoftware/datasets/covert-networks/baseballsteroiduse'
files = [('Baseball%20Steroid%20Use%20CSV.zip:CSV/BASEBALL_1M.csv', 'player-player', 'csv_matrix'), ('Baseball%20Steroid%20Use%20CSV.zip:CSV/BASEBALL_2M.csv', 'user-provider', 'csv_matrix')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=False)
        yield alt, g
