#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *
import csv

title = "Bitcoin transactions (2009-2013)"
description = """A network of Bitcoin transactions spanning January 2009 to April 2013. Nodes are public-key \"addresses\" at some time within the given period, and each edge is marked with the time (at a resolution of seconds) of the transaction.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Economic', 'Cryptocurrency', 'Unweighted', 'Timestamps']
url = 'https://dynamics.cs.washington.edu/data.html'
citation = [('M. Fire and C. Guestrin, "The Rise and Fall of Network Stars." Preprint, arXiv:1706.06690 (2017)', 'https://arxiv.org/abs/1706.06690')]
icon_hash = '5b313d48eb70bccf32ae3b2c'
ustream_license = None
upstream_prefix = 'https://dynamics.cs.washington.edu/nobackup/bitcoin'
files = [(('bitcoin.tar.gz:./bitcoin/bitcoin.links.csv',
           'bitcoin.tar.gz:./bitcoin/bitcoin.vertices.csv'), None, None)]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
#@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "r")) for fn in fnames]
            g = Graph()
            g.ep.count = count = g.new_ep("int")
            g.ep.max_date = max_date = g.new_ep("string")
            g.ep.min_date = min_date = g.new_ep("string")

            def get_lines():
                reader = csv.reader(fs[0], delimiter=",", quotechar='"')
                next(reader)
                for row in reader:
                    row[0] = int(row[0])
                    row[1] = int(row[1])
                    yield row

            g.add_edge_list(get_lines(), hashed=False,
                            eprops=[count, max_date, min_date])

            g.vp.first_transaction = first = g.new_vp("string")

            reader = csv.reader(fs[1], delimiter=",", quotechar='"')
            next(reader)
            for row in reader:
                v = int(row[0])
                first[v] = row[1]
        yield alt, g
