#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Bitcoin Alpha trust network (2017)"
description = """A network of who-trusts-whom relationships among users of the Bitcoin Alpha platform. Each directed edge (i,j,w) represents the rating of user j by user i, in which i assigns j a weight w on a scale of -10 (total distrust) to +10 (total trust) in steps of 1.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Online', 'Weighted', 'Signed', 'Timestamps']
url = 'http://snap.stanford.edu/data/soc-sign-bitcoinalpha.html'
citation = [('S. Kumar, F. Spezzano, V.S. Subrahmanian, and C. Faloutsos, "Edge weight prediction in weighted signed networks." IEEE 16th International Conference on Data Mining (ICDM), 221-230 (2016)', 'https://doi.org/10.1109/icdm.2016.0033')]
icon_hash = '5a8a5fa0d403934d2b3a3109'
ustream_license = None
upstream_prefix = 'https://snap.stanford.edu/data'
files = [('soc-sign-bitcoinalpha.csv.gz', None,
          ('csv', dict(props=["rating", "time"])))]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=True)
        yield alt, g
