#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Metabolic network (C. elegans)"
description = """List of edges comprising the metabolic network of the nematode C. elegans.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Biological', 'Metabolic', 'Unweighted']
url = 'https://deim.urv.cat/~alexandre.arenas/data/welcome.htm'
citation = [('J. Duch and A. Arenas, "Community identification using Extremal Optimization." Physical Review E 72, 027104 (2005).', 'https://doi.org/10.1103/physreve.72.027104')]
icon_hash = '56a85c8e26855e083a2f78d6'
ustream_license = None
upstream_prefix = 'http://deim.urv.cat/~alexandre.arenas/data/xarxes'
files = [('celegans_metabolic.zip:celegans_metabolic.net', None, 'pajek')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=False)
        yield alt, g
