#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Dutch college freshman (1995)"
description = """A small network of friendships among freshmen at Dutch College in 1994-1995. Friendship ties were surveyed at 7 different times over the year, and each edge is timestamped. The direction of an edge indicates that person i named person j, and the edge weight represents their level of friendship, ranging from -1 (risk of conflict) to +3 (best friend).[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Offline', 'Weighted', 'Timestamps']
url = 'http://konect.cc/networks/moreno_vdb'
citation = [('G. Van de Bunt, M. Van Duijn, & T. Snijders, "Friendship networks through time: An actor-oriented dynamic statistical network model." Comp. & Math. Org. Theory 5(2), 167-192 (1999)', 'https://doi.org/10.1023/A:1009683123448')]
icon_hash = '57e18bf28cf714f319c38bdc'
upstream_prefix = 'http://konect.cc/files'
files = [('download.tsv.moreno_vdb.tar.bz2', None, 'konect')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=True)
        yield alt, g
