#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Collins yeast interactome (2007)"
description = """Network of protein-protein interactions in Saccharomyces cerevisiae (budding yeast), measured by co-complex associations identified by high-throughput affinity purification and mass spectrometry (AP/MS)[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Biological', 'Protein interactions', 'Unweighted']
url = 'http://interactome.dfci.harvard.edu/S_cerevisiae/index.php?page=download'
citation = [('S.R. Collins et al., "Toward a comprehensive atlas of the physical interactome of Saccharomyces cerevisiae." Mol. Cell. Proteomics 6(3), 439-450 (2007)', 'https://doi.org/10.1074/mcp.m600381-mcp200')]
icon_hash = '56a85c8e26855e083a2f7946'
upstream_prefix = 'http://interactome.dfci.harvard.edu/S_cerevisiae/download'
files = [('Collins.txt', None, 'loadtxt')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=False)
        yield alt, g
