#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Haggle human proximity network (2006)"
description = """A network of human proximities, as measured by carried wireless devices. Each node represents a person, and an edge denotes when two people were within a certain proximity of each other, as measured by a wireless protocol (Bluetooth or Wifi). The edges are timestamped.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Offline', 'Unweighted', 'Timestamps']
url = 'http://konect.cc/networks/contact'
citation = [('A. Chaintreau et al. "Impact of human mobility on opportunistic forwarding algorithms." IEEE Trans. on Mobile Computing 6(6), 606-620 (2007).', 'https://doi.org/10.1109/tmc.2007.1060')]
icon_hash = '57cf1f0b67351c5e0ccd7a0d'
upstream_prefix = 'http://konect.cc/files'
files = [('download.tsv.contact.tar.bz2', None, 'konect')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=False)
        yield alt, g
