#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Global corporate directors (2016)"
description = """Bipartite network of directors and the companies on whose boards they sit, spanning 54 countries worldwide, constructed from data collected by the Financial Times (c. Sept. 2016). Person nodes are annotated with age and gender. Company nodes are annotated with their country, sector, industry, and number of employees.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Economic', 'Governance', 'Unweighted', 'Metadata']
url = 'https://doi.org/10.5281/zenodo.3553442'
citation = [('A. Evtushenko and M. T. Gastner, "Beyond Fortune 500: Women in a Global Network of Directors." In H. Cherifi et al. (Eds.), Complex Networks and Their Applications VIII, Volume 1, pp. 586-598 (2020)', 'https://arxiv.org/abs/1910.07441')]
icon_hash = '5de292ac4bbf13da17dc7c77'
ustream_license = None
upstream_prefix = 'https://zenodo.org/record/3553442/files'
files = [('board_director.gml.gz', None, 'gml')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=False)
        yield alt, g
