#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "DBLP authors (2016)"
description = """Scientific collaborations among authors of papers in the DBLP computer science bibliographic database. If an author i co-authored a paper with author j, the graph contains a undirected edge from i to j. If the paper is co-authored by k authors this generates a completely connected (sub)graph on k nodes (hence, this is a projection from a bipartite graph of authors and their publications). The date of this snapshot is uncertain.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Collaboration', 'Unweighted', 'Multigraph', 'Projection']
url = 'http://konect.cc/networks/dblp_coauthor'
citation = [('M. Ley, "The DBLP computer science bibliography: Evolution, research issues, perspectives." Proc. of the 9th Int. Symposium on String Processing and Information Retrieval (SPIRE), 1-10 (2002)', 'https://doi.org/10.1007/3-540-45735-6_1')]
icon_hash = '57574e51bd3e93b53c69556a'
upstream_prefix = 'http://konect.cc/files'
files = [('download.tsv.dblp_coauthor.tar.bz2', None, 'konect')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=False)
        yield alt, g
