#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "DBLP authors (2012)"
description = """A coauthorship network extracted from the DBLP computer science manuscript database, in 2012. This network is a one-mode projection from the bipartite graph of computer scientists and their publications.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Collaboration', 'Unweighted', 'Metadata', 'Projection']
url = 'http://snap.stanford.edu/data/com-DBLP.html'
citation = [('J. Yang and J. Leskovec. "Defining and Evaluating Network Communities based on Ground-truth." Proc. IEEE Internat. Conf. on Data Mining (ICDM 2012). arxiv:1205.6233', 'http://arxiv.org/abs/1205.6233')]
icon_hash = '56a85c8e26855e083a2f78d0'
ustream_license = None
upstream_prefix = 'https://snap.stanford.edu/data/bigdata/communities'
files = [(('com-dblp.ungraph.txt.gz', 'com-dblp.all.cmty.txt.gz'), None, "snap")]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph([fs[0]], fmt, directed=False)
            g.vp.communities = c = g.new_vp("vector<int>")

            with io.TextIOWrapper(fs[1], "utf8") as f:
                for i, line in enumerate(f):
                    for x in line.split():
                        v = int(x)
                        c[v].append(i)

        yield alt, g
