#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Dutch literacy criticism (1976)"
description = """A network of criticisms among Dutch literary authors in 1976. The directed edge (i,j) denotes that an author i passed judgment on author j's work in an interview or review.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Offline', 'Unweighted']
url = 'http://vlado.fmf.uni-lj.si/pub/networks/data/esna/literature.htm'
citation = [('W. De Nooy, "A literary playground: Literary criticism and balance theory." Poetics 26 (5-6), 385-404 (1999).', 'https://doi.org/10.1016/s0304-422x(99)00009-1')]
icon_hash = '58ef763f62da63251186890d'
upstream_prefix = 'http://vlado.fmf.uni-lj.si/pub/networks/data/esna'
files = [('literature.zip:literature_1976.net', None, 'pajek')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=True)
        yield alt, g
