#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Dutch school friendships (2003)"
description = """A series of snapshots of the friendships among freshmen at secondary school in The Netherlands, in 2003-2004. Friendship ties were surveyed four times, at three month intervals. The direction of an edge indicates that student i is friends with student j. Missing data is coded as 0 or 10. Metadata includes sex, age, ethnicity, and religion.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Offline', 'Unweighted', 'Metadata', 'Temporal']
url = 'http://www.stats.ox.ac.uk/~snijders/siena/tutorial2010_data.htm'
citation = [('T. Snijders, G. van de Bunt, and C. Steglich, "Introduction to stochastic actor-based models for network dynamics." Social Networks 32(1), 44-60 (2010)', 'https://doi.org/10.1016/j.socnet.2009.02.004')]
icon_hash = '5944a99b4ed8f1bb6022a49b'
upstream_prefix = 'http://www.stats.ox.ac.uk/~snijders/siena'
files = [('klas12b.zip:klas12b-net-1.dat', 'klas12b-net-1', 'matrix'), ('klas12b.zip:klas12b-net-2.dat', 'klas12b-net-2', 'matrix'), ('klas12b.zip:klas12b-net-3.dat', 'klas12b-net-3', 'matrix'), ('klas12b.zip:klas12b-net-3m.dat', 'klas12b-net-3m', 'matrix'), ('klas12b.zip:klas12b-net-4.dat', 'klas12b-net-4', 'matrix'), ('klas12b.zip:klas12b-net-4m.dat', 'klas12b-net-4m', 'matrix'), ('klas12b.zip:klas12b-primary.dat', 'klas12b-primary', 'matrix')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=True)
        yield alt, g
