#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "E. coli transcription network (2002)"
description = """Network of operons and their pairwise interactions, via transcription factor-based regulation, within the bacteria Escherichia coli[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Biological', 'Gene regulation', 'Unweighted']
url = 'http://www.weizmann.ac.il/mcb/UriAlon/e-coli-transcription-network'
citation = [('Shen-Orr et. al, "Network motifs in the transcriptional regulation network of Escherichia coli." Nature Genetics 31, 64-68 (2002).', 'https://doi.org/10.1038/ng881')]
icon_hash = '56a85c8e26855e083a2f78ee'
upstream_prefix = 'https://www.weizmann.ac.il/mcb/UriAlon/sites/mcb.UriAlon/files/uploads/Network_motifs_in_coli'
files = [(('colinet-1.0.zip:ColiNet-1.0/coliInterFullVec.txt', 'colinet-1.0.zip:ColiNet-1.0/coliInterFullNames.txt'), 'v1.0', ('loadtxt', {'pnames': ['regulation_type'], 'vprops': {'fmt': 'txt', 'names': ['name']}})), (('colinet-1.1.zip:ColiNet-1.1/coliInterFullVec.txt', 'colinet-1.1.zip:ColiNet-1.1/coliInterFullNames.txt'), 'v1.1', ('loadtxt', {'pnames': ['regulation_type'], 'vprops': {'fmt': 'txt', 'names': ['name']}}))]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=True)
        yield alt, g
