#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Wikipedia book edits (2010)"
description = """Two bipartite user-page networks extracted from Wikipedia, about books. A user connects to a page if that user edited that page. Edits (edges) are timestamped. Edge weights represent counts of the number of edits.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Informational', 'Web graph', 'Multigraph', 'Timestamps']
url = 'http://konect.cc/networks/edit-enwikibooks'
citation = [('"Wikimedia Foundation. Wikimedia downloads."', 'http://dumps.wikimedia.org/')]
icon_hash = '5751a5d3bd3e93b53c6954ca'
upstream_prefix = 'http://konect.cc/files'
files = [('download.tsv.edit-aawikibooks.tar.bz2', 'aa', 'konect'), ('download.tsv.edit-afwikibooks.tar.bz2', 'af', 'konect'), ('download.tsv.edit-akwikibooks.tar.bz2', 'ak', 'konect'), ('download.tsv.edit-alswikibooks.tar.bz2', 'als', 'konect'), ('download.tsv.edit-angwikibooks.tar.bz2', 'ang', 'konect'), ('download.tsv.edit-arwikibooks.tar.bz2', 'ar', 'konect'), ('download.tsv.edit-astwikibooks.tar.bz2', 'ast', 'konect'), ('download.tsv.edit-aswikibooks.tar.bz2', 'as', 'konect'), ('download.tsv.edit-azwikibooks.tar.bz2', 'az', 'konect'), ('download.tsv.edit-bewikibooks.tar.bz2', 'be', 'konect'), ('download.tsv.edit-bgwikibooks.tar.bz2', 'bg', 'konect'), ('download.tsv.edit-biwikibooks.tar.bz2', 'bi', 'konect'), ('download.tsv.edit-bmwikibooks.tar.bz2', 'bm', 'konect'), ('download.tsv.edit-bnwikibooks.tar.bz2', 'bn', 'konect'), ('download.tsv.edit-bowikibooks.tar.bz2', 'bo', 'konect'), ('download.tsv.edit-bswikibooks.tar.bz2', 'bs', 'konect'), ('download.tsv.edit-cawikibooks.tar.bz2', 'ca', 'konect'), ('download.tsv.edit-chwikibooks.tar.bz2', 'ch', 'konect'), ('download.tsv.edit-cowikibooks.tar.bz2', 'co', 'konect'), ('download.tsv.edit-cswikibooks.tar.bz2', 'cs', 'konect'), ('download.tsv.edit-cvwikibooks.tar.bz2', 'cv', 'konect'), ('download.tsv.edit-cywikibooks.tar.bz2', 'cy', 'konect'), ('download.tsv.edit-dawikibooks.tar.bz2', 'da', 'konect'), ('download.tsv.edit-dewikibooks.tar.bz2', 'de', 'konect'), ('download.tsv.edit-elwikibooks.tar.bz2', 'el', 'konect'), ('download.tsv.edit-enwikibooks.tar.bz2', 'en', 'konect'), ('download.tsv.edit-eowikibooks.tar.bz2', 'eo', 'konect'), ('download.tsv.edit-eswikibooks.tar.bz2', 'es', 'konect'), ('download.tsv.edit-etwikibooks.tar.bz2', 'et', 'konect'), ('download.tsv.edit-euwikibooks.tar.bz2', 'eu', 'konect'), ('download.tsv.edit-fawikibooks.tar.bz2', 'fa', 'konect'), ('download.tsv.edit-fiwikibooks.tar.bz2', 'fi', 'konect'), ('download.tsv.edit-frwikibooks.tar.bz2', 'fr', 'konect'), ('download.tsv.edit-fywikibooks.tar.bz2', 'fy', 'konect'), ('download.tsv.edit-glwikibooks.tar.bz2', 'gl', 'konect'), ('download.tsv.edit-gnwikibooks.tar.bz2', 'gn', 'konect'), ('download.tsv.edit-gotwikibooks.tar.bz2', 'got', 'konect'), ('download.tsv.edit-guwikibooks.tar.bz2', 'gu', 'konect'), ('download.tsv.edit-hewikibooks.tar.bz2', 'he', 'konect'), ('download.tsv.edit-hiwikibooks.tar.bz2', 'hi', 'konect'), ('download.tsv.edit-hrwikibooks.tar.bz2', 'hr', 'konect'), ('download.tsv.edit-huwikibooks.tar.bz2', 'hu', 'konect'), ('download.tsv.edit-hywikibooks.tar.bz2', 'hy', 'konect'), ('download.tsv.edit-iawikibooks.tar.bz2', 'ia', 'konect'), ('download.tsv.edit-idwikibooks.tar.bz2', 'id', 'konect'), ('download.tsv.edit-iewikibooks.tar.bz2', 'ie', 'konect'), ('download.tsv.edit-iswikibooks.tar.bz2', 'is', 'konect'), ('download.tsv.edit-itwikibooks.tar.bz2', 'it', 'konect'), ('download.tsv.edit-jawikibooks.tar.bz2', 'ja', 'konect'), ('download.tsv.edit-kawikibooks.tar.bz2', 'ka', 'konect'), ('download.tsv.edit-kkwikibooks.tar.bz2', 'kk', 'konect'), ('download.tsv.edit-kmwikibooks.tar.bz2', 'km', 'konect'), ('download.tsv.edit-knwikibooks.tar.bz2', 'kn', 'konect'), ('download.tsv.edit-kowikibooks.tar.bz2', 'ko', 'konect'), ('download.tsv.edit-kswikibooks.tar.bz2', 'ks', 'konect'), ('download.tsv.edit-kuwikibooks.tar.bz2', 'ku', 'konect'), ('download.tsv.edit-kywikibooks.tar.bz2', 'ky', 'konect'), ('download.tsv.edit-lawikibooks.tar.bz2', 'la', 'konect'), ('download.tsv.edit-lbwikibooks.tar.bz2', 'lb', 'konect'), ('download.tsv.edit-liwikibooks.tar.bz2', 'li', 'konect'), ('download.tsv.edit-lnwikibooks.tar.bz2', 'ln', 'konect'), ('download.tsv.edit-ltwikibooks.tar.bz2', 'lt', 'konect'), ('download.tsv.edit-lvwikibooks.tar.bz2', 'lv', 'konect'), ('download.tsv.edit-mgwikibooks.tar.bz2', 'mg', 'konect'), ('download.tsv.edit-miwikibooks.tar.bz2', 'mi', 'konect'), ('download.tsv.edit-mkwikibooks.tar.bz2', 'mk', 'konect'), ('download.tsv.edit-mlwikibooks.tar.bz2', 'ml', 'konect'), ('download.tsv.edit-mnwikibooks.tar.bz2', 'mn', 'konect'), ('download.tsv.edit-mrwikibooks.tar.bz2', 'mr', 'konect'), ('download.tsv.edit-mswikibooks.tar.bz2', 'ms', 'konect'), ('download.tsv.edit-mywikibooks.tar.bz2', 'my', 'konect'), ('download.tsv.edit-nahwikibooks.tar.bz2', 'nah', 'konect'), ('download.tsv.edit-nawikibooks.tar.bz2', 'na', 'konect'), ('download.tsv.edit-ndswikibooks.tar.bz2', 'nds', 'konect'), ('download.tsv.edit-newikibooks.tar.bz2', 'ne', 'konect'), ('download.tsv.edit-nlwikibooks.tar.bz2', 'nl', 'konect'), ('download.tsv.edit-nowikibooks.tar.bz2', 'no', 'konect'), ('download.tsv.edit-ocwikibooks.tar.bz2', 'oc', 'konect'), ('download.tsv.edit-pawikibooks.tar.bz2', 'pa', 'konect'), ('download.tsv.edit-plwikibooks.tar.bz2', 'pl', 'konect'), ('download.tsv.edit-pswikibooks.tar.bz2', 'ps', 'konect'), ('download.tsv.edit-ptwikibooks.tar.bz2', 'pt', 'konect'), ('download.tsv.edit-quwikibooks.tar.bz2', 'qu', 'konect'), ('download.tsv.edit-rmwikibooks.tar.bz2', 'rm', 'konect'), ('download.tsv.edit-rowikibooks.tar.bz2', 'ro', 'konect'), ('download.tsv.edit-ruwikibooks.tar.bz2', 'ru', 'konect'), ('download.tsv.edit-sawikibooks.tar.bz2', 'sa', 'konect'), ('download.tsv.edit-sewikibooks.tar.bz2', 'se', 'konect'), ('download.tsv.edit-simplewikibooks.tar.bz2', 'simple', 'konect'), ('download.tsv.edit-siwikibooks.tar.bz2', 'si', 'konect'), ('download.tsv.edit-skwikibooks.tar.bz2', 'sk', 'konect'), ('download.tsv.edit-slwikibooks.tar.bz2', 'sl', 'konect'), ('download.tsv.edit-sqwikibooks.tar.bz2', 'sq', 'konect'), ('download.tsv.edit-srwikibooks.tar.bz2', 'sr', 'konect'), ('download.tsv.edit-suwikibooks.tar.bz2', 'su', 'konect'), ('download.tsv.edit-svwikibooks.tar.bz2', 'sv', 'konect'), ('download.tsv.edit-swwikibooks.tar.bz2', 'sw', 'konect'), ('download.tsv.edit-tawikibooks.tar.bz2', 'ta', 'konect'), ('download.tsv.edit-tewikibooks.tar.bz2', 'te', 'konect'), ('download.tsv.edit-tgwikibooks.tar.bz2', 'tg', 'konect'), ('download.tsv.edit-thwikibooks.tar.bz2', 'th', 'konect'), ('download.tsv.edit-tkwikibooks.tar.bz2', 'tk', 'konect'), ('download.tsv.edit-tlwikibooks.tar.bz2', 'tl', 'konect'), ('download.tsv.edit-trwikibooks.tar.bz2', 'tr', 'konect'), ('download.tsv.edit-ttwikibooks.tar.bz2', 'tt', 'konect'), ('download.tsv.edit-ugwikibooks.tar.bz2', 'ug', 'konect'), ('download.tsv.edit-ukwikibooks.tar.bz2', 'uk', 'konect'), ('download.tsv.edit-urwikibooks.tar.bz2', 'ur', 'konect'), ('download.tsv.edit-uzwikibooks.tar.bz2', 'uz', 'konect'), ('download.tsv.edit-viwikibooks.tar.bz2', 'vi', 'konect'), ('download.tsv.edit-vowikibooks.tar.bz2', 'vo', 'konect'), ('download.tsv.edit-wawikibooks.tar.bz2', 'wa', 'konect'), ('download.tsv.edit-xhwikibooks.tar.bz2', 'xh', 'konect'), ('download.tsv.edit-yowikibooks.tar.bz2', 'yo', 'konect'), ('download.tsv.edit-zawikibooks.tar.bz2', 'za', 'konect'), ('download.tsv.edit-zh_min_nanwikibooks.tar.bz2', 'zh_min_nan', 'konect'), ('download.tsv.edit-zhwikibooks.tar.bz2', 'zh', 'konect'), ('download.tsv.edit-zuwikibooks.tar.bz2', 'zu', 'konect')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=False)
        yield alt, g
