#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Wikipedia news edits (2010)"
description = """Two bipartite user-page networks extracted from Wikipedia, about news events. A user connects to a page if that user edited that page. Edits (edges) are timestamped. Edge weights represent counts of the number of edits.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Informational', 'Web graph', 'Multigraph', 'Timestamps']
url = 'http://konect.cc/networks/edit-enwikinews'
citation = [('"Wikimedia Foundation. Wikimedia downloads."', 'http://dumps.wikimedia.org/')]
icon_hash = '5751a6bcbd3e93b53c6954cd'
upstream_prefix = 'http://konect.cc/files'
files = [('download.tsv.edit-arwikinews.tar.bz2', 'ar', 'konect'), ('download.tsv.edit-bgwikinews.tar.bz2', 'bg', 'konect'), ('download.tsv.edit-bswikinews.tar.bz2', 'bs', 'konect'), ('download.tsv.edit-cawikinews.tar.bz2', 'ca', 'konect'), ('download.tsv.edit-cswikinews.tar.bz2', 'cs', 'konect'), ('download.tsv.edit-dewikinews.tar.bz2', 'de', 'konect'), ('download.tsv.edit-elwikinews.tar.bz2', 'el', 'konect'), ('download.tsv.edit-enwikinews.tar.bz2', 'en', 'konect'), ('download.tsv.edit-eowikinews.tar.bz2', 'eo', 'konect'), ('download.tsv.edit-eswikinews.tar.bz2', 'es', 'konect'), ('download.tsv.edit-fawikinews.tar.bz2', 'fa', 'konect'), ('download.tsv.edit-fiwikinews.tar.bz2', 'fi', 'konect'), ('download.tsv.edit-frwikinews.tar.bz2', 'fr', 'konect'), ('download.tsv.edit-hewikinews.tar.bz2', 'he', 'konect'), ('download.tsv.edit-huwikinews.tar.bz2', 'hu', 'konect'), ('download.tsv.edit-itwikinews.tar.bz2', 'it', 'konect'), ('download.tsv.edit-jawikinews.tar.bz2', 'ja', 'konect'), ('download.tsv.edit-kowikinews.tar.bz2', 'ko', 'konect'), ('download.tsv.edit-nlwikinews.tar.bz2', 'nl', 'konect'), ('download.tsv.edit-nowikinews.tar.bz2', 'no', 'konect'), ('download.tsv.edit-plwikinews.tar.bz2', 'pl', 'konect'), ('download.tsv.edit-ptwikinews.tar.bz2', 'pt', 'konect'), ('download.tsv.edit-rowikinews.tar.bz2', 'ro', 'konect'), ('download.tsv.edit-ruwikinews.tar.bz2', 'ru', 'konect'), ('download.tsv.edit-sdwikinews.tar.bz2', 'sd', 'konect'), ('download.tsv.edit-sqwikinews.tar.bz2', 'sq', 'konect'), ('download.tsv.edit-srwikinews.tar.bz2', 'sr', 'konect'), ('download.tsv.edit-svwikinews.tar.bz2', 'sv', 'konect'), ('download.tsv.edit-tawikinews.tar.bz2', 'ta', 'konect'), ('download.tsv.edit-thwikinews.tar.bz2', 'th', 'konect'), ('download.tsv.edit-trwikinews.tar.bz2', 'tr', 'konect'), ('download.tsv.edit-ukwikinews.tar.bz2', 'uk', 'konect'), ('download.tsv.edit-zhwikinews.tar.bz2', 'zh', 'konect')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=False)
        yield alt, g
