#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Wikiquote edits (2010)"
description = """A bipartite user-page network extracted from Wikiquotes. A user connects to a page if that user edited that page. Edits (edges) are timestamped. Edge weights represent counts of the number of edits.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Informational', 'Web graph', 'Multigraph', 'Timestamps']
url = 'http://konect.cc/networks/edit-enwikiquote'
citation = [('"Wikimedia Foundation. Wikimedia downloads."', 'http://dumps.wikimedia.org/')]
icon_hash = '5757192dbd3e93b53c695544'
upstream_prefix = 'http://konect.cc/files'
files = [('download.tsv.edit-afwikiquote.tar.bz2', 'af', 'konect'), ('download.tsv.edit-alswikiquote.tar.bz2', 'als', 'konect'), ('download.tsv.edit-amwikiquote.tar.bz2', 'am', 'konect'), ('download.tsv.edit-angwikiquote.tar.bz2', 'ang', 'konect'), ('download.tsv.edit-arwikiquote.tar.bz2', 'ar', 'konect'), ('download.tsv.edit-astwikiquote.tar.bz2', 'ast', 'konect'), ('download.tsv.edit-azwikiquote.tar.bz2', 'az', 'konect'), ('download.tsv.edit-bewikiquote.tar.bz2', 'be', 'konect'), ('download.tsv.edit-bgwikiquote.tar.bz2', 'bg', 'konect'), ('download.tsv.edit-bmwikiquote.tar.bz2', 'bm', 'konect'), ('download.tsv.edit-brwikiquote.tar.bz2', 'br', 'konect'), ('download.tsv.edit-bswikiquote.tar.bz2', 'bs', 'konect'), ('download.tsv.edit-cawikiquote.tar.bz2', 'ca', 'konect'), ('download.tsv.edit-cowikiquote.tar.bz2', 'co', 'konect'), ('download.tsv.edit-cswikiquote.tar.bz2', 'cs', 'konect'), ('download.tsv.edit-cywikiquote.tar.bz2', 'cy', 'konect'), ('download.tsv.edit-dawikiquote.tar.bz2', 'da', 'konect'), ('download.tsv.edit-dewikiquote.tar.bz2', 'de', 'konect'), ('download.tsv.edit-elwikiquote.tar.bz2', 'el', 'konect'), ('download.tsv.edit-enwikiquote.tar.bz2', 'en', 'konect'), ('download.tsv.edit-eowikiquote.tar.bz2', 'eo', 'konect'), ('download.tsv.edit-eswikiquote.tar.bz2', 'es', 'konect'), ('download.tsv.edit-etwikiquote.tar.bz2', 'et', 'konect'), ('download.tsv.edit-euwikiquote.tar.bz2', 'eu', 'konect'), ('download.tsv.edit-fawikiquote.tar.bz2', 'fa', 'konect'), ('download.tsv.edit-fiwikiquote.tar.bz2', 'fi', 'konect'), ('download.tsv.edit-frwikiquote.tar.bz2', 'fr', 'konect'), ('download.tsv.edit-gawikiquote.tar.bz2', 'ga', 'konect'), ('download.tsv.edit-glwikiquote.tar.bz2', 'gl', 'konect'), ('download.tsv.edit-guwikiquote.tar.bz2', 'gu', 'konect'), ('download.tsv.edit-hewikiquote.tar.bz2', 'he', 'konect'), ('download.tsv.edit-hiwikiquote.tar.bz2', 'hi', 'konect'), ('download.tsv.edit-hrwikiquote.tar.bz2', 'hr', 'konect'), ('download.tsv.edit-huwikiquote.tar.bz2', 'hu', 'konect'), ('download.tsv.edit-hywikiquote.tar.bz2', 'hy', 'konect'), ('download.tsv.edit-idwikiquote.tar.bz2', 'id', 'konect'), ('download.tsv.edit-iswikiquote.tar.bz2', 'is', 'konect'), ('download.tsv.edit-itwikiquote.tar.bz2', 'it', 'konect'), ('download.tsv.edit-jawikiquote.tar.bz2', 'ja', 'konect'), ('download.tsv.edit-kawikiquote.tar.bz2', 'ka', 'konect'), ('download.tsv.edit-kkwikiquote.tar.bz2', 'kk', 'konect'), ('download.tsv.edit-knwikiquote.tar.bz2', 'kn', 'konect'), ('download.tsv.edit-kowikiquote.tar.bz2', 'ko', 'konect'), ('download.tsv.edit-krwikiquote.tar.bz2', 'kr', 'konect'), ('download.tsv.edit-kswikiquote.tar.bz2', 'ks', 'konect'), ('download.tsv.edit-kuwikiquote.tar.bz2', 'ku', 'konect'), ('download.tsv.edit-kywikiquote.tar.bz2', 'ky', 'konect'), ('download.tsv.edit-lawikiquote.tar.bz2', 'la', 'konect'), ('download.tsv.edit-lbwikiquote.tar.bz2', 'lb', 'konect'), ('download.tsv.edit-liwikiquote.tar.bz2', 'li', 'konect'), ('download.tsv.edit-ltwikiquote.tar.bz2', 'lt', 'konect'), ('download.tsv.edit-mlwikiquote.tar.bz2', 'ml', 'konect'), ('download.tsv.edit-mrwikiquote.tar.bz2', 'mr', 'konect'), ('download.tsv.edit-nlwikiquote.tar.bz2', 'nl', 'konect'), ('download.tsv.edit-nnwikiquote.tar.bz2', 'nn', 'konect'), ('download.tsv.edit-nowikiquote.tar.bz2', 'no', 'konect'), ('download.tsv.edit-plwikiquote.tar.bz2', 'pl', 'konect'), ('download.tsv.edit-ptwikiquote.tar.bz2', 'pt', 'konect'), ('download.tsv.edit-rowikiquote.tar.bz2', 'ro', 'konect'), ('download.tsv.edit-ruwikiquote.tar.bz2', 'ru', 'konect'), ('download.tsv.edit-sawikiquote.tar.bz2', 'sa', 'konect'), ('download.tsv.edit-simplewikiquote.tar.bz2', 'simple', 'konect'), ('download.tsv.edit-skwikiquote.tar.bz2', 'sk', 'konect'), ('download.tsv.edit-slwikiquote.tar.bz2', 'sl', 'konect'), ('download.tsv.edit-sqwikiquote.tar.bz2', 'sq', 'konect'), ('download.tsv.edit-srwikiquote.tar.bz2', 'sr', 'konect'), ('download.tsv.edit-suwikiquote.tar.bz2', 'su', 'konect'), ('download.tsv.edit-svwikiquote.tar.bz2', 'sv', 'konect'), ('download.tsv.edit-tawikiquote.tar.bz2', 'ta', 'konect'), ('download.tsv.edit-tewikiquote.tar.bz2', 'te', 'konect'), ('download.tsv.edit-thwikiquote.tar.bz2', 'th', 'konect'), ('download.tsv.edit-tkwikiquote.tar.bz2', 'tk', 'konect'), ('download.tsv.edit-trwikiquote.tar.bz2', 'tr', 'konect'), ('download.tsv.edit-ttwikiquote.tar.bz2', 'tt', 'konect'), ('download.tsv.edit-ugwikiquote.tar.bz2', 'ug', 'konect'), ('download.tsv.edit-ukwikiquote.tar.bz2', 'uk', 'konect'), ('download.tsv.edit-urwikiquote.tar.bz2', 'ur', 'konect'), ('download.tsv.edit-uzwikiquote.tar.bz2', 'uz', 'konect'), ('download.tsv.edit-viwikiquote.tar.bz2', 'vi', 'konect'), ('download.tsv.edit-vowikiquote.tar.bz2', 'vo', 'konect'), ('download.tsv.edit-wowikiquote.tar.bz2', 'wo', 'konect'), ('download.tsv.edit-zh_min_nanwikiquote.tar.bz2', 'zh_min_nan', 'konect'), ('download.tsv.edit-zhwikiquote.tar.bz2', 'zh', 'konect')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=False)
        yield alt, g
