#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Wiktionary edits (2010)"
description = """Three bipartite user-page networks extracted from Wiktionary,  for French, German, and English. A user connects to a page if that user edited that page. Edits (edges) are timestamped. Edge weights represent counts of the number of edits.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Informational', 'Web graph', 'Multigraph', 'Timestamps']
url = 'http://konect.cc/networks/edit-frwiktionary'
citation = [('"Wikimedia Foundation. Wikimedia downloads."', 'http://dumps.wikimedia.org/')]
icon_hash = '5751aad9bd3e93b53c6954e1'
upstream_prefix = 'http://konect.cc/files'
files = [('download.tsv.edit-aawiktionary.tar.bz2', 'aa', 'konect'), ('download.tsv.edit-abwiktionary.tar.bz2', 'ab', 'konect'), ('download.tsv.edit-afwiktionary.tar.bz2', 'af', 'konect'), ('download.tsv.edit-akwiktionary.tar.bz2', 'ak', 'konect'), ('download.tsv.edit-alswiktionary.tar.bz2', 'als', 'konect'), ('download.tsv.edit-amwiktionary.tar.bz2', 'am', 'konect'), ('download.tsv.edit-angwiktionary.tar.bz2', 'ang', 'konect'), ('download.tsv.edit-anwiktionary.tar.bz2', 'an', 'konect'), ('download.tsv.edit-arwiktionary.tar.bz2', 'ar', 'konect'), ('download.tsv.edit-astwiktionary.tar.bz2', 'ast', 'konect'), ('download.tsv.edit-aswiktionary.tar.bz2', 'as', 'konect'), ('download.tsv.edit-avwiktionary.tar.bz2', 'av', 'konect'), ('download.tsv.edit-aywiktionary.tar.bz2', 'ay', 'konect'), ('download.tsv.edit-azwiktionary.tar.bz2', 'az', 'konect'), ('download.tsv.edit-bewiktionary.tar.bz2', 'be', 'konect'), ('download.tsv.edit-bgwiktionary.tar.bz2', 'bg', 'konect'), ('download.tsv.edit-bhwiktionary.tar.bz2', 'bh', 'konect'), ('download.tsv.edit-biwiktionary.tar.bz2', 'bi', 'konect'), ('download.tsv.edit-bmwiktionary.tar.bz2', 'bm', 'konect'), ('download.tsv.edit-bnwiktionary.tar.bz2', 'bn', 'konect'), ('download.tsv.edit-bowiktionary.tar.bz2', 'bo', 'konect'), ('download.tsv.edit-brwiktionary.tar.bz2', 'br', 'konect'), ('download.tsv.edit-bswiktionary.tar.bz2', 'bs', 'konect'), ('download.tsv.edit-cawiktionary.tar.bz2', 'ca', 'konect'), ('download.tsv.edit-chrwiktionary.tar.bz2', 'chr', 'konect'), ('download.tsv.edit-chwiktionary.tar.bz2', 'ch', 'konect'), ('download.tsv.edit-cowiktionary.tar.bz2', 'co', 'konect'), ('download.tsv.edit-crwiktionary.tar.bz2', 'cr', 'konect'), ('download.tsv.edit-csbwiktionary.tar.bz2', 'csb', 'konect'), ('download.tsv.edit-cswiktionary.tar.bz2', 'cs', 'konect'), ('download.tsv.edit-cywiktionary.tar.bz2', 'cy', 'konect'), ('download.tsv.edit-dawiktionary.tar.bz2', 'da', 'konect'), ('download.tsv.edit-dewiktionary.tar.bz2', 'de', 'konect'), ('download.tsv.edit-dvwiktionary.tar.bz2', 'dv', 'konect'), ('download.tsv.edit-dzwiktionary.tar.bz2', 'dz', 'konect'), ('download.tsv.edit-elwiktionary.tar.bz2', 'el', 'konect'), ('download.tsv.edit-enwiktionary.tar.bz2', 'en', 'konect'), ('download.tsv.edit-eowiktionary.tar.bz2', 'eo', 'konect'), ('download.tsv.edit-eswiktionary.tar.bz2', 'es', 'konect'), ('download.tsv.edit-etwiktionary.tar.bz2', 'et', 'konect'), ('download.tsv.edit-euwiktionary.tar.bz2', 'eu', 'konect'), ('download.tsv.edit-fawiktionary.tar.bz2', 'fa', 'konect'), ('download.tsv.edit-fiwiktionary.tar.bz2', 'fi', 'konect'), ('download.tsv.edit-fjwiktionary.tar.bz2', 'fj', 'konect'), ('download.tsv.edit-fowiktionary.tar.bz2', 'fo', 'konect'), ('download.tsv.edit-frwiktionary.tar.bz2', 'fr', 'konect'), ('download.tsv.edit-fywiktionary.tar.bz2', 'fy', 'konect'), ('download.tsv.edit-gawiktionary.tar.bz2', 'ga', 'konect'), ('download.tsv.edit-gdwiktionary.tar.bz2', 'gd', 'konect'), ('download.tsv.edit-glwiktionary.tar.bz2', 'gl', 'konect'), ('download.tsv.edit-gnwiktionary.tar.bz2', 'gn', 'konect'), ('download.tsv.edit-guwiktionary.tar.bz2', 'gu', 'konect'), ('download.tsv.edit-gvwiktionary.tar.bz2', 'gv', 'konect'), ('download.tsv.edit-hawiktionary.tar.bz2', 'ha', 'konect'), ('download.tsv.edit-hewiktionary.tar.bz2', 'he', 'konect'), ('download.tsv.edit-hiwiktionary.tar.bz2', 'hi', 'konect'), ('download.tsv.edit-hrwiktionary.tar.bz2', 'hr', 'konect'), ('download.tsv.edit-hsbwiktionary.tar.bz2', 'hsb', 'konect'), ('download.tsv.edit-huwiktionary.tar.bz2', 'hu', 'konect'), ('download.tsv.edit-hywiktionary.tar.bz2', 'hy', 'konect'), ('download.tsv.edit-iawiktionary.tar.bz2', 'ia', 'konect'), ('download.tsv.edit-idwiktionary.tar.bz2', 'id', 'konect'), ('download.tsv.edit-iewiktionary.tar.bz2', 'ie', 'konect'), ('download.tsv.edit-ikwiktionary.tar.bz2', 'ik', 'konect'), ('download.tsv.edit-iowiktionary.tar.bz2', 'io', 'konect'), ('download.tsv.edit-iswiktionary.tar.bz2', 'is', 'konect'), ('download.tsv.edit-itwiktionary.tar.bz2', 'it', 'konect'), ('download.tsv.edit-iuwiktionary.tar.bz2', 'iu', 'konect'), ('download.tsv.edit-jawiktionary.tar.bz2', 'ja', 'konect'), ('download.tsv.edit-jbowiktionary.tar.bz2', 'jbo', 'konect'), ('download.tsv.edit-jvwiktionary.tar.bz2', 'jv', 'konect'), ('download.tsv.edit-kawiktionary.tar.bz2', 'ka', 'konect'), ('download.tsv.edit-kkwiktionary.tar.bz2', 'kk', 'konect'), ('download.tsv.edit-klwiktionary.tar.bz2', 'kl', 'konect'), ('download.tsv.edit-kmwiktionary.tar.bz2', 'km', 'konect'), ('download.tsv.edit-knwiktionary.tar.bz2', 'kn', 'konect'), ('download.tsv.edit-kowiktionary.tar.bz2', 'ko', 'konect'), ('download.tsv.edit-kswiktionary.tar.bz2', 'ks', 'konect'), ('download.tsv.edit-kuwiktionary.tar.bz2', 'ku', 'konect'), ('download.tsv.edit-kwwiktionary.tar.bz2', 'kw', 'konect'), ('download.tsv.edit-kywiktionary.tar.bz2', 'ky', 'konect'), ('download.tsv.edit-lawiktionary.tar.bz2', 'la', 'konect'), ('download.tsv.edit-lbwiktionary.tar.bz2', 'lb', 'konect'), ('download.tsv.edit-liwiktionary.tar.bz2', 'li', 'konect'), ('download.tsv.edit-lnwiktionary.tar.bz2', 'ln', 'konect'), ('download.tsv.edit-lowiktionary.tar.bz2', 'lo', 'konect'), ('download.tsv.edit-ltwiktionary.tar.bz2', 'lt', 'konect'), ('download.tsv.edit-lvwiktionary.tar.bz2', 'lv', 'konect'), ('download.tsv.edit-mgwiktionary.tar.bz2', 'mg', 'konect'), ('download.tsv.edit-mhwiktionary.tar.bz2', 'mh', 'konect'), ('download.tsv.edit-miwiktionary.tar.bz2', 'mi', 'konect'), ('download.tsv.edit-mkwiktionary.tar.bz2', 'mk', 'konect'), ('download.tsv.edit-mlwiktionary.tar.bz2', 'ml', 'konect'), ('download.tsv.edit-mnwiktionary.tar.bz2', 'mn', 'konect'), ('download.tsv.edit-mowiktionary.tar.bz2', 'mo', 'konect'), ('download.tsv.edit-mrwiktionary.tar.bz2', 'mr', 'konect'), ('download.tsv.edit-mswiktionary.tar.bz2', 'ms', 'konect'), ('download.tsv.edit-mtwiktionary.tar.bz2', 'mt', 'konect'), ('download.tsv.edit-mywiktionary.tar.bz2', 'my', 'konect'), ('download.tsv.edit-nahwiktionary.tar.bz2', 'nah', 'konect'), ('download.tsv.edit-nawiktionary.tar.bz2', 'na', 'konect'), ('download.tsv.edit-ndswiktionary.tar.bz2', 'nds', 'konect'), ('download.tsv.edit-newiktionary.tar.bz2', 'ne', 'konect'), ('download.tsv.edit-nlwiktionary.tar.bz2', 'nl', 'konect'), ('download.tsv.edit-nnwiktionary.tar.bz2', 'nn', 'konect'), ('download.tsv.edit-nowiktionary.tar.bz2', 'no', 'konect'), ('download.tsv.edit-ocwiktionary.tar.bz2', 'oc', 'konect'), ('download.tsv.edit-omwiktionary.tar.bz2', 'om', 'konect'), ('download.tsv.edit-orwiktionary.tar.bz2', 'or', 'konect'), ('download.tsv.edit-pawiktionary.tar.bz2', 'pa', 'konect'), ('download.tsv.edit-plwiktionary.tar.bz2', 'pl', 'konect'), ('download.tsv.edit-pnbwiktionary.tar.bz2', 'pnb', 'konect'), ('download.tsv.edit-pswiktionary.tar.bz2', 'ps', 'konect'), ('download.tsv.edit-ptwiktionary.tar.bz2', 'pt', 'konect'), ('download.tsv.edit-quwiktionary.tar.bz2', 'qu', 'konect'), ('download.tsv.edit-rmwiktionary.tar.bz2', 'rm', 'konect'), ('download.tsv.edit-rnwiktionary.tar.bz2', 'rn', 'konect'), ('download.tsv.edit-roa_rupwiktionary.tar.bz2', 'roa_rup', 'konect'), ('download.tsv.edit-rowiktionary.tar.bz2', 'ro', 'konect'), ('download.tsv.edit-ruwiktionary.tar.bz2', 'ru', 'konect'), ('download.tsv.edit-rwwiktionary.tar.bz2', 'rw', 'konect'), ('download.tsv.edit-sawiktionary.tar.bz2', 'sa', 'konect'), ('download.tsv.edit-scnwiktionary.tar.bz2', 'scn', 'konect'), ('download.tsv.edit-scwiktionary.tar.bz2', 'sc', 'konect'), ('download.tsv.edit-sdwiktionary.tar.bz2', 'sd', 'konect'), ('download.tsv.edit-sgwiktionary.tar.bz2', 'sg', 'konect'), ('download.tsv.edit-shwiktionary.tar.bz2', 'sh', 'konect'), ('download.tsv.edit-simplewiktionary.tar.bz2', 'simple', 'konect'), ('download.tsv.edit-siwiktionary.tar.bz2', 'si', 'konect'), ('download.tsv.edit-skwiktionary.tar.bz2', 'sk', 'konect'), ('download.tsv.edit-slwiktionary.tar.bz2', 'sl', 'konect'), ('download.tsv.edit-smwiktionary.tar.bz2', 'sm', 'konect'), ('download.tsv.edit-snwiktionary.tar.bz2', 'sn', 'konect'), ('download.tsv.edit-sowiktionary.tar.bz2', 'so', 'konect'), ('download.tsv.edit-sqwiktionary.tar.bz2', 'sq', 'konect'), ('download.tsv.edit-srwiktionary.tar.bz2', 'sr', 'konect'), ('download.tsv.edit-sswiktionary.tar.bz2', 'ss', 'konect'), ('download.tsv.edit-stwiktionary.tar.bz2', 'st', 'konect'), ('download.tsv.edit-suwiktionary.tar.bz2', 'su', 'konect'), ('download.tsv.edit-svwiktionary.tar.bz2', 'sv', 'konect'), ('download.tsv.edit-swwiktionary.tar.bz2', 'sw', 'konect'), ('download.tsv.edit-tawiktionary.tar.bz2', 'ta', 'konect'), ('download.tsv.edit-tewiktionary.tar.bz2', 'te', 'konect'), ('download.tsv.edit-tgwiktionary.tar.bz2', 'tg', 'konect'), ('download.tsv.edit-thwiktionary.tar.bz2', 'th', 'konect'), ('download.tsv.edit-tiwiktionary.tar.bz2', 'ti', 'konect'), ('download.tsv.edit-tkwiktionary.tar.bz2', 'tk', 'konect'), ('download.tsv.edit-tlwiktionary.tar.bz2', 'tl', 'konect'), ('download.tsv.edit-tnwiktionary.tar.bz2', 'tn', 'konect'), ('download.tsv.edit-towiktionary.tar.bz2', 'to', 'konect'), ('download.tsv.edit-tpiwiktionary.tar.bz2', 'tpi', 'konect'), ('download.tsv.edit-trwiktionary.tar.bz2', 'tr', 'konect'), ('download.tsv.edit-tswiktionary.tar.bz2', 'ts', 'konect'), ('download.tsv.edit-ttwiktionary.tar.bz2', 'tt', 'konect'), ('download.tsv.edit-twwiktionary.tar.bz2', 'tw', 'konect'), ('download.tsv.edit-ugwiktionary.tar.bz2', 'ug', 'konect'), ('download.tsv.edit-ukwiktionary.tar.bz2', 'uk', 'konect'), ('download.tsv.edit-urwiktionary.tar.bz2', 'ur', 'konect'), ('download.tsv.edit-uzwiktionary.tar.bz2', 'uz', 'konect'), ('download.tsv.edit-vecwiktionary.tar.bz2', 'vec', 'konect'), ('download.tsv.edit-viwiktionary.tar.bz2', 'vi', 'konect'), ('download.tsv.edit-vowiktionary.tar.bz2', 'vo', 'konect'), ('download.tsv.edit-wawiktionary.tar.bz2', 'wa', 'konect'), ('download.tsv.edit-wowiktionary.tar.bz2', 'wo', 'konect'), ('download.tsv.edit-xhwiktionary.tar.bz2', 'xh', 'konect'), ('download.tsv.edit-yiwiktionary.tar.bz2', 'yi', 'konect'), ('download.tsv.edit-yowiktionary.tar.bz2', 'yo', 'konect'), ('download.tsv.edit-zawiktionary.tar.bz2', 'za', 'konect'), ('download.tsv.edit-zh_min_nanwiktionary.tar.bz2', 'zh_min_nan', 'konect'), ('download.tsv.edit-zhwiktionary.tar.bz2', 'zh', 'konect'), ('download.tsv.edit-zuwiktionary.tar.bz2', 'zu', 'konect')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=False)
        yield alt, g
