#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Manufacturing company email (2010)"
description = """A network of emails among employee email addresses at a mid-sized manufacturing company. Each directed edge represents an email sent from address i to address j. Edges are timestamped, and occurred over a 6 month period in an unspecified year.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Communication', 'Unweighted', 'Multigraph', 'Timestamps']
url = 'http://konect.cc/networks/radoslaw_email'
citation = [('R. Michalski, S. Palus, and P. Kazienko, "Matching organizational structure and social network extracted from email communication." In Lecture Notes in Business Information Processing 87, 197-206 (2011)', 'https://doi.org/10.1007/978-3-642-21863-7_17')]
icon_hash = '575758dfbd3e93b53c69557d'
upstream_prefix = 'http://konect.cc/files'
files = [('download.tsv.radoslaw_email.tar.bz2', None, 'konect')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=True)
        yield alt, g
