#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Email network (Enron corpus)"
description = """The Enron email corpus, containing all the email communication from the Enron corporation, which was made public as a result of legal action. Nodes are email addresses and node i links to node j if i sent at least one email to address j. Non-Enron email addresses are also present, but only their links to/from Enron addresses are observed.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Communication', 'Unweighted', 'Multigraph', 'Timestamps']
url = 'https://doi.org/10.1007/978-3-540-30115-8_22'
citation = [('B. Klimt and Y. Yang, "The Enron Corpus: A New Dataset for Email Classification Research." Proc. Eur. Conf. Machine Learning (ECML), 217-226 (2004).', 'https://doi.org/10.1007/978-3-540-30115-8_22')]
icon_hash = '56a85c8e26855e083a2f78b6'
ustream_license = None
upstream_prefix = 'http://snap.stanford.edu/data'
files = [('email-Enron.txt.gz', None, 'snap')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=True)
        yield alt, g
