#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Epinions product ratings (2005)"
description = """A bipartite network of users and the products they rated on the website Epinions.com. A user connects to all products on which that user entered a rating. Edge weight represents the rating score, and edges are timestamped.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Economic', 'Preferences', 'Timestamps', 'Weighted']
url = 'http://konect.cc/networks/epinions-rating'
citation = [('P. Massa and P Avesani. "Controversial users demand local trust metrics: An experimental study on epinions. com community." Proc. of the Internat. Conf. on AI (AAAI 2005).', 'http://www.aaai.org/Papers/AAAI/2005/AAAI05-020.pdf')]
icon_hash = '5818e7ac8cf714f319c3eae6'
upstream_prefix = 'http://konect.cc/files'
files = [('download.tsv.epinions-rating.tar.bz2', None, 'konect')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=True)
        yield alt, g
