#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *
import csv

title = "Brazilian prostitution network (2010)"
description = """A bipartite network of escort and individuals who buy sex from them in Brazil, extracted from a Brazilian online community for such ratings. Edges represent a purchase of sexual intercourse with an escort, and the edge weight gives the buyer's rating of the escort: -1 (bad), 0 (neutral), or +1 (good). Other edge attributes are available. Edges are timestamped.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Public Health', 'Weighted', 'Timestamps']
url = 'https://doi.org/10.1371/journal.pcbi.1001109'
citation = [('L. Rocha, F. Liljeros, & P. Holme. "Simulated epidemics in an empirical spatiotemporal network of 50,185 sexual contacts." PLoS Comput Biol, 7(3). (2011).', 'https://doi.org/10.1371/journal.pcbi.1001109')]
icon_hash = '5832214b8cf714f319c427a0'
upstream_prefix = 'https://doi.org/10.1371'
files = [('journal.pcbi.1001109.s001', None, 'csv')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "r")) for fn in fnames]
            g = Graph(directed=True)
            reader = csv.reader(fs[0], delimiter=";")
            def edges():
                for row in reader:
                    if len(row) == 1:
                        continue
                    yield [int(x) for x in row]
            eprops = ["time", "rating", "anal", "oral", "kiss"]
            for p in eprops:
                g.ep[p] = g.new_ep("int")
            g.add_edge_list(edges(), hashed=False,
                            eprops=[g.ep[p] for p in eprops])
            g.vp.male = g.new_vp("bool")
            g.vp.male.a = g.degree_property_map("out").a > 0
            g.set_directed(False)
        yield alt, g
