#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Faculty hiring networks (Comp. Sci., Business, History)"
description = """Three networks of faculty hiring in Computer Science Departments, Business Schools, and History Departments. Each node is a PhD-granting institution in the respective field, and a directed edge (i,j) indicates that a person received their PhD from node i and was tenure-track faculty at node j during time of collection (2011-2013). All data collected from faculty public rosters at the sampled institutions[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Economic', 'Employment', 'Weighted', 'Metadata']
url = 'https://aaronclauset.github.io/facultyhiring/'
citation = [('A. Clauset, S. Arbesman, and D. B. Larremore, "Systematic inequality and hierarchy in faculty hiring networks." Science Advances 1(1), e1400005 (2015).', 'https://doi.org/10.1126/sciadv.1400005')]
icon_hash = '56a85c8e26855e083a2f7925'
ustream_license = None
upstream_prefix = 'https://aaronclauset.github.io/facultyhiring/'
files = [(('ComputerScience_edgelist.txt', 'ComputerScience_vertexlist.txt'), 'computer_science', ("csv", {"vprops":{"fmt":"csv"}})),
         (('Business_edgelist.txt', 'Business_vertexlist.txt'), 'business', ("csv", {"vprops":{"fmt":"csv"}})),
         (('History_edgelist.txt', 'History_vertexlist.txt'), 'history', ("csv", {"vprops":{"fmt":"csv"}}))]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=True)
        yield alt, g
