#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "FAO Multiplex Trade Network"
description = """Multiplex network representing trade relationships between countries from the Food and Agricultural Organization of the United Nations.  Countries are nodes and edge types represent import/export of varying products.  Data hosted by Manlio De Domenico.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Economic', 'Trade', 'Weighted', 'Multilayer']
url = 'https://manliodedomenico.com/data.php'
citation = [('M. De Domenico, V. Nicosia, A. Arenas and V. Latora, "Structural reducibility of multilayer networks". Nature Communications 6, 6864 (2015)', 'https://doi.org/10.1038/ncomms7864')]
icon_hash = '56e9da14a6d70217090cdf15'
ustream_license = ('Open Data Commons Open Database License (ODbL)', 'https://opendatacommons.org/licenses/odbl/')
upstream_prefix = 'https://manliodedomenico.com/data'
files = [('FAO_Multiplex_Trade.zip', None, 'comunelab')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=True)
        yield alt, g
