#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "NCAA college football 2000 (corrected metadata)"
description = r"""A network of American football games between Division IA colleges during regular season Fall 2000. This version contains some corrections made by T. S. Evans, in particular:

There are are two issues with the original GN file. First three teams met twice in one season so the graph is not simple. This is easily dealt with if required. Secondly, the assignments to conferences, the node values, seem to be for the 2001 season and not the 2000 season. The games do appear to be for the 2000 season as stated. For instance the Big West conference existed for football till 2000 while the Sun Belt conference was only started in 2001. Also there were 11 conferences and 5 independents in 2001 but 10 conferences and 8 independents in 2000. I have provided a set of files footballTSE* which define a simple graph with the correct conference assignments in the archive here."""
tags = ['Social', 'Sports', 'Unweighted']
url = 'https://figshare.com/articles/American_College_Football_Network_Files/93179'
citation = [('M. Girvan and M. E. J. Newman, "Community structure in social and biological networks." Proc. Natl. Acad. Sci. USA 99(12), 7821-7826 (2002).', 'https://doi.org/10.1073/pnas.122653799'),
            ('T.S. Evans, "Clique Graphs and Overlapping Communities", J. Stat. Mech. (2010) P12037', 'https://doi.org/10.1088/1742-5468/2010/12/P12037')]
icon_hash = None
ustream_license = None
upstream_prefix = 'https://ndownloader.figshare.com/files'
files = [('94935:zip:footballTSEinput.gml', None, 'gml')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=False)
        yield alt, g
