#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Freshwater stream webs"
description = """A set of 26 networks of trophic-level species interactions in streams in New Zealand, Maine and North Carolina. Networks include the identities of aquatic insect, algae and fish species and their trophic interactions. Excel and plain text adjacency matrices available; webs can be downloaded individually or as a group[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Biological', 'Food web', 'Unweighted', 'Metadata']
url = 'https://iwdb.nceas.ucsb.edu/html/thomps_towns.html'
citation = [('R.M. Thompson and C.R. Townsend, "Impacts on stream food webs of native and exotic forest: an intercontinental comparison." Ecology 84, 145-161 (2003).', 'https://doi.org/10.1890/0012-9658(2003)084[0145:iosfwo]2.0.co;2')]
icon_hash = '56a85c8e26855e083a2f78f1'
ustream_license = None
upstream_prefix = 'https://iwdb.nceas.ucsb.edu/data/predator_prey/text_matrices'
files = [('thomps_towns_text.zip:AkatoreAtxt.txt', 'AkatoreA', 'matrix'),
         ('thomps_towns_text.zip:AkatoreBtxt.txt', 'AkatoreB', 'matrix'),
         ('thomps_towns_text.zip:Berwicktxt.txt', 'Berwick', 'matrix'),
         ('thomps_towns_text.zip:Blackrocktxt.txt', 'Blackrock', 'matrix'),
         ('thomps_towns_text.zip:Broadtxt.txt', 'Broad', 'matrix'),
         ('thomps_towns_text.zip:Cantontxt.txt', 'Canton', 'matrix'),
         ('thomps_towns_text.zip:Catlinstxt.txt', 'Catlins', 'matrix'),
         ('thomps_towns_text.zip:Coweeta1txt.txt', 'Coweeta1', 'matrix'),
         ('thomps_towns_text.zip:Coweeta17txt.txt', 'Coweeta17', 'matrix'),
         ('thomps_towns_text.zip:DempstersAutxt.txt', 'DempstersAu', 'matrix'),
         ('thomps_towns_text.zip:DempstersSptxt.txt', 'DempstersSp', 'matrix'),
         ('thomps_towns_text.zip:DempstersSutxt.txt', 'DempstersSu', 'matrix'),
         ('thomps_towns_text.zip:Germantxt.txt', 'German', 'matrix'),
         ('thomps_towns_text.zip:Healytxt.txt', 'Healy', 'matrix'),
         ('thomps_towns_text.zip:Kyeburntxt.txt', 'Kyeburn', 'matrix'),
         ('thomps_towns_text.zip:LilKyeburntxt.txt', 'LilKyeburn', 'matrix'),
         ('thomps_towns_text.zip:Martinstxt.txt', 'Martins', 'matrix'),
         ('thomps_towns_text.zip:Narrowdaletxt.txt', 'Narrowdale', 'matrix'),
         ('thomps_towns_text.zip:NorthColtxt.txt', 'NorthCol', 'matrix'),
         ('thomps_towns_text.zip:Powdertxt.txt', 'Powder', 'matrix'),
         ('thomps_towns_text.zip:Stonytxt.txt', 'Stony', 'matrix'),
         ('thomps_towns_text.zip:SuttonAutxt.txt', 'SuttonAu', 'matrix'),
         ('thomps_towns_text.zip:SuttonSptxt.txt', 'SuttonSp', 'matrix'),
         ('thomps_towns_text.zip:SuttonSutxt.txt', 'SuttonSu', 'matrix'),
         ('thomps_towns_text.zip:Troytxt.txt', 'Troy', 'matrix'),
         ('thomps_towns_text.zip:Venlawtxt.txt', 'Venlaw', 'matrix')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=True)
        yield alt, g
