#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Zeggelink's freshmen (1999)"
description = """Snapshots of friendships among freshmen majoring in Sociology at the University of Groningen, collected five times over the 1998-1999 year. The direction of an edge indicates that student i is friends with student j, and the edge weight gives their friendship level from 1 (best friend) to 5 (troubled relation). Metadata include gender, age, program type, and smoking behavior.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Offline', 'Weighted', 'Temporal', 'Metadata']
url = 'http://www.stats.ox.ac.uk/~snijders/siena/Zeggelink_data.htm'
citation = [('G. Van de Bunt, M. Van Duijn, and T. Snijders. "Friendship networks through time: An actor-oriented dynamic statistical network model." Computational & Mathematical Organization Theory 5.2. 167-192. (1999).', 'https://doi.org/10.1023/A:1009683123448')]
icon_hash = '595b2427549f067e0263b551'
upstream_prefix = 'https://www.stats.ox.ac.uk/~snijders/siena'
files = [(('DataEvelien_98_99.zip:stu98t0.txt', 'DataEvelien_98_99.zip:stud98.txt'), 't0', ('matrix', {'vprops': {'fmt': 'txt', 'names': ['id', 'gender', 'age', 'program', 'smoking']}})), (('DataEvelien_98_99.zip:stu98t2.txt', 'DataEvelien_98_99.zip:stud98.txt'), 't2', ('matrix', {'vprops': {'fmt': 'txt', 'names': ['id', 'gender', 'age', 'program', 'smoking']}})), (('DataEvelien_98_99.zip:stu98t3.txt', 'DataEvelien_98_99.zip:stud98.txt'), 't3', ('matrix', {'vprops': {'fmt': 'txt', 'names': ['id', 'gender', 'age', 'program', 'smoking']}})), (('DataEvelien_98_99.zip:stu98t5.txt', 'DataEvelien_98_99.zip:stud98.txt'), 't5', ('matrix', {'vprops': {'fmt': 'txt', 'names': ['id', 'gender', 'age', 'program', 'smoking']}})), (('DataEvelien_98_99.zip:stu98t6.txt', 'DataEvelien_98_99.zip:stud98.txt'), 't6', ('matrix', {'vprops': {'fmt': 'txt', 'names': ['id', 'gender', 'age', 'program', 'smoking']}}))]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=True)
        yield alt, g
