#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Fullerene molecular structures"
description = """Fifteen networks of carbon atoms and the atomic bonds that connect them within molecules of fullerenes, from 60 atoms up to 6000 atoms. A bond is defined to exist whenever the distance of two atoms is less than 1.5 angstrom.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Biological', 'Chemical', 'Unweighted', 'Spatial']
url = 'https://doi.org/10.6084/m9.figshare.5700832'
citation = [('S. Aref and M. C. Wilson, "Balance and frustration in signed networks." J. Complex Networks 7(2), 163–189 (2019)', 'https://doi.org/10.1093/comnet/cny015')]
icon_hash = '5e25280d78691ca4060b74ae'
ustream_license = None
upstream_prefix = 'https://ndownloader.figshare.com/files'
files = [(f"21172485:zip:Molecular graphs of fullerene/Fullerenes graphs in gml format/Fullerene {net}.gml", net, "gml")
         for net in ["C1500", "C180", "C2160", "C240", "C260", "C2940", "C320",
                     "C3840", "C4860", "C500", "C540", "C6000", "C60", "C720",
                     "C960"]]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=False)
        yield alt, g
