#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Multiplex genetic interactions (2014)"
description = """Multiplex networks representing different types of genetic interactions, for different organisms. Layers represent (i) physical, (ii) association, (iii) co-localization, (iv) direct, and (v) suppressive, (vi) additive or synthetic genetic interaction. Edge direction (i,j) indicates gene i interacting with gene j.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Biological', 'Gene regulation', 'Protein interactions', 'Unweighted', 'Multilayer']
url = 'https://manliodedomenico.com/data.php'
citation = [('M. De Domenico, M. A. Porter, & A. Arenas. "MuxViz: a tool for multilayer analysis and visualization of networks". Journal of Complex Networks, cnu038. (2014).', 'https://doi.org/10.1093/comnet/cnu038')]
icon_hash = '58851617a411221d0e7c676b'
ustream_license = ('Open Data Commons Open Database License (ODbL)', 'https://opendatacommons.org/licenses/odbl/')
upstream_prefix = 'https://manliodedomenico.com/data'
files = [('Arabidopsis_Multiplex_Genetic.zip', 'Arabidopsis', 'comunelab'),
         ('Bos_Multiplex_Genetic.zip', 'Bos_Multiplex_Genetic', 'comunelab'),
         ('Candida_Multiplex_Genetic.zip', 'Candida', 'comunelab'),
         ('Celegans_Multiplex_Genetic.zip', 'Celegans', 'comunelab'),
         ('Drosophila_Multiplex_Genetic.zip', 'Drosophila', 'comunelab'),
         ('DanioRerio_Multiplex_Genetic.zip', 'DanioRerio', 'comunelab'),
         ('Gallus_Multiplex_Genetic.zip', 'Gallus', 'comunelab'),
         ('HepatitusCVirus_Multiplex_Genetic.zip', 'HepatitusCVirus', 'comunelab'),
         ('Homo_Multiplex_Genetic.zip', 'Homo', 'comunelab'),
         ('HumanHerpes4_Multiplex_Genetic.zip', 'HumanHerpes4', 'comunelab'),
         ('HumanHIV1_Multiplex_Genetic.zip', 'HumanHIV1', 'comunelab'),
         ('Mus_Multiplex_Genetic.zip', 'Mus', 'comunelab'),
         ('Oryctolagus_Multiplex_Genetic.zip', 'Oryctolagus', 'comunelab'),
         ('Plasmodium_Multiplex_Genetic.zip', 'Plasmodium', 'comunelab'),
         ('Rattus_Multiplex_Genetic.zip', 'Rattus', 'comunelab'),
         ('SacchCere_Multiplex_Genetic.zip', 'Sacchcere', 'comunelab'),
         ('SacchPomb_Multiplex_Genetic.zip', 'Sacchpomb', 'comunelab'),
         ('Xenopus_Multiplex_Genetic.zip', 'Xenopus', 'comunelab'),
         ('YeastLandscape_Multiplex_Genetic.zip', 'YeastLandscape', 'comunelab')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=True)
        yield alt, g
