#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Gnutella p2p networks (2002)"
description = """A sequence of 9 snapshots of the Gnutella peer-to-peer file sharing network from 5-31 August 2002. Nodes are hosts in the Gnutella network topology and edges are connections between them.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Technological', 'Peer-to-peer', 'Unweighted']
url = 'http://snap.stanford.edu/data/p2p-Gnutella04.html'
citation = [('M. Ripeanu and I. Foster and A. Iamnitchi. "Mapping the Gnutella Network: Properties of Large-Scale Peer-to-Peer Systems and Implications for System Design." IEEE Internet Comp. Journal 6(1), 50-57 (2002).', 'https://doi.org/10.1007/3-540-45748-8_8')]
icon_hash = '56a85c8e26855e083a2f78bc'
ustream_license = None
upstream_prefix = 'https://snap.stanford.edu/data'
files = [(f'p2p-Gnutella{d}.txt.gz', f"{d}", "snap")
         for d in ["04", "06", "08", "09", "24", "25", "30", "31"]]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=True)
        yield alt, g
