#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "White Leghorn hens (1946)"
description = """Dominance interactions (pecking) among a group of White Leghorn hens, observed in 1946. Edge weights represent the frequency of interaction. The two versions below are equivalent.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Animal', 'Weighted']
url = 'http://konect.cc/networks/moreno_hens'
citation = [('A.M. Guhl. "Social behavior of the domestic fowl." Manhattan, Kansas: Kansas State College, Agricultural Experiment Station, Technical Bulletin 73 (1953)', 'https://doi.org/10.2307/3627156')]
icon_hash = '57349f90461efe0c7a67832c'
upstream_prefix = 'http://konect.cc/files'
files = [('download.tsv.moreno_hens.tar.bz2', None, 'konect')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=True)
        yield alt, g
