#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Krackhardt high tech company network"
description = """Multiplex network of 3 edge types representing relationships (advice, friendship, and “reports to”) between managers of a high-tech company.  Data hosted by Manlio De Domenico.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Offline', 'Multilayer', 'Unweighted']
url = 'https://manliodedomenico.com/data.php'
citation = [('D. Krackhardt, "Cognitive social structures". Social Networks (1987), 9, 104-134.', 'https://doi.org/10.1016/0378-8733(87)90009-8')]
icon_hash = '56ce71c7a6d70217090cdba2'
upstream_license = ("Open Data Commons Open Database License (ODbL)",
                    "https://opendatacommons.org/licenses/odbl/")
upstream_prefix = 'https://manliodedomenico.com/data'
files = [('Krackhardt-High-Tech_Multiplex_Social.zip', None, 'comunelab')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=True)
        yield alt, g
