#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "JUNG and javax class dependencies (2012)"
description = """A network of software class dependency within the JUNG 2.0.1 and javax 1.6.0.7 library namespaces edu.uci.ics.jung and java/javax. Nodes represent classes and a directed edge indicates a dependency of one class on another.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Technological', 'Software', 'Unweighted']
url = 'http://konect.cc/networks/subelj_jung-j'
citation = [('L. Šubelj and M. Bajec. "Software systems through complex networks science: Review, analysis and applications." Proc. 1st Internat. Workshop on Software Mining (2012)', 'https://doi.org/10.1145/2384416.2384418')]
icon_hash = '5840fa738cf714f319c4540d'
upstream_prefix = 'http://konect.cc/files'
files = [('download.tsv.subelj_jung-j.tar.bz2', None, 'konect')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=True)
        yield alt, g
