#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Zachary Karate Club"
description = """Network of friendships among members of a university karate club. Includes metadata for faction membership after a social partition. Note: there are two versions of this network, one with 77 edges and one with 78, due to an ambiguous typo in the original study. (The most commonly used is the one with 78 edges.)[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Offline', 'Unweighted']
url = 'https://aaronclauset.github.io/datacode.htm'
citation = [('W. W. Zachary, "An information flow model for conflict and fission in small groups." Journal of Anthropological Research 33, 452-473 (1977).', 'https://doi.org/10.1086/jar.33.4.3629752')]
icon_hash = '56a85c8e26855e083a2f789e'
ustream_license = None
upstream_prefix = "https://aaronclauset.github.io/data"
files = [(('zkcc-77.zip:zkcc-77/karate_edges_77.txt',
           'zkcc-77.zip:zkcc-77/karate_groups.txt'), '77', 'loadtxt'),
         (('zkcc-77.zip:zkcc-77/karate_edges_77.txt',
           'zkcc-77.zip:zkcc-77/karate_groups.txt'), '78', 'loadtxt')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]

            g = Graph(directed=False)
            edges = numpy.loadtxt(fs[0], dtype="int")
            g.vp.name = g.add_edge_list(edges, hashed=True, hash_type="int")
            remove_parallel_edges(g)
            groups = numpy.loadtxt(fs[1], dtype="int")
            g.vp.groups = g.new_vp("int")
            vs = {g.vp.name[v]:v for v in g.vertices()}
            for v, r in groups:
                g.vp.groups[vs[v]] = r
            idx = g.vp.name.copy("int")

            if alt == "78":
                g.add_edge(vs[23], vs[34])

            g = Graph(g, vorder=idx)
        yield alt, g
