#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Abu Sayyaf kidnappings (2014)"
description = """Bipartite network of members of the Abu Sayyaf Group in the Philippines, and the kidnapping events they were involved in.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Offline', 'Unweighted']
url = 'https://sites.google.com/site/ucinetsoftware/datasets/covert-networks/philippinekidnappings'
citation = [('L. Gerdes, K. Ringler, and B. Autin, "Assessing the Abu Sayyaf Group\'s Strategic and Learning Capacities." Studies in Conflict & Terrorism 37(3), 267-293 (2014)', 'https://doi.org/10.1080/1057610x.2014.872021')]
icon_hash = '59dae666ee01e9ab21aadc68'
upstream_prefix = 'https://sites.google.com/site/ucinetsoftware/datasets/covert-networks/philippinekidnappings'
files = [('Philippine%20Kidnappings%20CSV.zip:CSV/PHILKIDNAP_2M.csv', None, 'csv_matrix')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=True)
        yield alt, g
