#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Libimseti.cz social network (2012)"
description = """A network of ratings given between users at Libimseti.cz, a Czech online dating website. A directed edge (i,j) means that user i rate user j, and the corresponding edge weight is the given rating, on a scale of 1-10.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Online', 'Weighted']
url = 'http://konect.cc/networks/libimseti'
citation = [('J. Kunegis, G Gröner, and T Gottron. "Online dating recommender systems: The split-complex number approach." Proc. 4th ACM RecSys Workshop on Recommender Systems and the Social Web (2012)', 'https://doi.org/10.1145/2365934.2365942')]
icon_hash = '583226a48cf714f319c427a5'
upstream_prefix = 'http://konect.cc/files'
files = [('download.tsv.libimseti.tar.bz2', None, 'konect')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=True)
        yield alt, g
