#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "LiveJournal social network (2006)"
description = """The LiveJournal online social network of relationships among its nearly 10 million members in 2006. LJ members may maintain journals, individual and group blogs, and members may declare which other members are their friends.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Online', 'Unweighted']
url = 'https://doi.org/10.1145/1150402.1150412'
citation = [('L. Backstrom, D. Huttenlocher, J. Kleinberg, and X. Lan. "Group Formation in Large Social Networks: Membership, Growth, and Evolution." Proc. Internat. Conf. on Knowledge Discovery and Data Mining (KDD), 44-54 (2006).', 'https://doi.org/10.1145/1150402.1150412')]
icon_hash = '56a85c8e26855e083a2f78b2'
upstream_prefix = 'https://snap.stanford.edu/data'
files = [('soc-LiveJournal1.txt.gz', None, 'snap')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=True)
        yield alt, g
