#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Livejournal social graph"
description = """This network contains the social graph of Livejournal, a free on-line social network where users can keep a blog, journal or diary, where a directed edge (i,j) means that user i follows user j.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Online', 'Unweighted']
url = 'https://lfs.aminer.cn/lab-datasets/multi-sns/'
citation = [('T. Chen, M. A. Kaafar, A. Friedman, and R. Boreli. "Is more always merrier?: a deep dive into online social footprints." In 2012 ACM workshop on Workshop on online social networks, pages 67–72, 2012.', 'https://doi.org/10.1145/2342549.2342565'),
            ('D. Perito, C. Castelluccia, M. A. Kaafar, and P. Manils. "How unique and traceable are usernames? In Privacy Enhancing Technologies", pages 1–17. Springer, 2011', 'https://doi.org/10.1007/978-3-642-22263-4_1'),
            ('H. Kwak, C. Lee, H. Park, and S. Moon. "What is Twitter, a social network or a news media?" In WWW ’10: Proceedings of the 19th international conference on World wide web, pages 591–600, New York, NY, USA, 2010. ACM.','https://doi.org/10.1145/1772690.1772751'),
            ('Yutao Zhang, Jie Tang, "Social Network Integration: Towards Constructing the Social Graph", arxiv:1311.2670','https://arxiv.org/abs/1311.2670')]
icon_hash = '595b194b549f067e0263b535'
ustream_license = None
upstream_prefix = 'https://lfs.aminer.cn/lab-datasets/multi-sns'
files = [("livejournal.tar.gz:livejournal.edges", None, None)]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fname, alt, fmt in files:
        with open_upstream_file(name, fname, "r") as f:
            def get_line():
                for line in f:
                    vals = [int(x) for x in line.split()]
                    vals[0], vals[1] = vals[1], vals[0]
                    yield vals
            g = Graph(directed=True)
            g.vp.name = g.add_edge_list(get_line(), hashed=True)
        yield alt, g
