#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *
from scipy.io import loadmat

title = "Macaque cortical connectivity (Young)"
description = """A network of cortical regions in the Macaque cortex[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Biological', 'Connectome', 'Unweighted']
url = 'https://sites.google.com/site/bctnet/datasets'
citation = [('M.P. Young, "The organization of neural systems in the primate cerebral cortex." Proc. R. Soc. London B 252,13-18 (1993)', 'https://doi.org/10.1098/rspb.1993.0040')]
icon_hash = '56a85c8e26855e083a2f7922'
upstream_prefix = 'https://sites.google.com/site/bctnet/Home/functions'
files = [('macaque47.mat', None, 'matlab')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fname, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        with open_upstream_file(name, fname, "rb") as f:
            m = loadmat(f)
            g = Graph(directed=False)
            a = m["CIJ"]
            for i in range(a.shape[0]):
                for j in range(a.shape[1]):
                    if a[i,j] > 0:
                        g.add_edge(i, j)
            g.vp.name = g.new_vp("string")
            for i, n in enumerate(m["Names"]):
                g.vp.name[i] = n
        yield alt, g
