#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "The Marker Cafe (2011)"
description = """Snapshot of connections among users of the Israeli social network Marker Cafe, collected in 2011. Nodes are users and a directed edge (i,j) represents user i added user j to i's circle.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Online', 'Unweighted']
url = 'https://data4goodlab.github.io/MichaelFire/#section3'
citation = [('M. Fire et al. "Computationally efficient link prediction in a variety of social networks." ACM Transactions on Intelligent Systems and Technology 5(1), Article 10 (2013)', 'https://doi.org/10.1145/2542182.2542192')]
icon_hash = '59fe969bee01e9ab21ac7fca'
ustream_license = None
upstream_prefix = 'https://data4goodlab.github.io/MichaelFire/datasets'
files = [('TheMarkerAnonymized.zip:TheMarkerAnonymized/TheMarkerAnonymized.csv', None, 'csv')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=False)
        yield alt, g
