#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

import json

title = "Marvel character partnerships (2018)"
description = """A network of partnerships among characters in the Marvel comic book universe. Nodes are either heroes or villains, and edges represent partnerships between such characters. The partnership network was extracted from Wikipedia pages of these characters, which indicate partnership relations with other such pages.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Fictional', 'Unweighted']
url = 'http://ix.io/1omF'
citation = [('"Ulf Aslak (@ulfaslak) Tweet", Twitter (2018)', 'https://twitter.com/ulfaslak/status/1048126665338101760')]
icon_hash = '5bcb8ae2197c3f8a02723137'
ustream_license = None
upstream_prefix = 'http://ix.io'
files = [('1omF', None, None)]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "r")) for fn in fnames]
            g = Graph(directed=False)
            d = json.load(fs[0])
            g.vp.id = g.new_vp("string")
            g.vp.group = g.new_vp("int")
            g.vp.size = g.new_vp("int")
            for node in d["nodes"]:
                v = g.add_vertex()
                g.vp.id[v] = node["id"]
                g.vp.group[v] = node["group"]
                g.vp.size[v] = node["size"]
            vs = {g.vp.id[v] : v for v in g.vertices()}
            for edge in d["links"]:
                u = vs[edge["source"]]
                v = vs[edge["target"]]
                e = g.add_edge(u, v)
        yield alt, g
