#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Microsoft Concept Graph"
description = """A bipartite network of relations among \"instances\" and \"concepts,\" like named entities, actions, objects, etc., mined from the World Wide Web and assembled using statistical techniques into a database called Probase. Edge weights represent the frequency of association between a concept and an instance. Access to data must be requested; this version is the \"core IsA\" graph.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Informational', 'Relatedness', 'Weighted']
url = 'https://concept.research.microsoft.com/Home/Download'
citation = [('Z. Wang et al., "An Inference Approach to Basic Level of Categorization." Proc. ACM Internat. Conf. on Info. and Know. Management (CIKM 2015)', 'https://doi.org/10.1145/2806416.2806533')]
icon_hash = '581a03518cf714f319c3ee25'
ustream_license = None
upstream_prefix = 'https://concept.research.microsoft.com/Home'
files = [('StartDownload:zip:data-concept/data-concept-instance-relations.txt', None, None)]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force, bad_ssl=True)

@cache_network()
#@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fname, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        with open_upstream_file(name, fname, "r") as f:
            g = Graph(directed=False)
            g.ep.count = g.new_ep("int")
            def get_lines():
                for line in f:
                    vals = line.split("\t")
                    yield vals
            g.vp.name = g.add_edge_list(get_lines(), hashed=True,
                                        hash_type="string", eprops=[g.ep.count])
        yield alt, g
