#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Montreal street gangs (2007)"
description = """Network representing relationships between gangs, obtained from Montreal Police’s central intelligence database, spanning 2004 to 2007. Nodes are gangs, and an edge represents some kind of relationship between two gangs (as elicited from interviews with gang members).[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Affiliation', 'Unweighted']
url = 'https://sites.google.com/site/ucinetsoftware/datasets/covert-networks/montrealstreetgangs'
citation = [('K. Descormiers, and C. Morselli, "Alliances, conflicts, and contradictions in Montreal’s street gang landscape." International Criminal Justice Review 21(3), 297-314 (2011)', 'https://doi.org/10.1177/1057567711418501')]
icon_hash = '59f95347ee01e9ab21ac1eee'
upstream_prefix = 'https://28915467-a-62cb3a1a-s-sites.googlegroups.com/site/ucinetsoftware/datasets/covert-networks/montrealstreetgangs'
files = [(('Montreal%20Street%20Gangs%20CSV.zip:CSV/MONTREALGANG.csv', 'Montreal%20Street%20Gangs%20CSV.zip:CSV/MONTREALGANG_ATTR.csv'), None, ('csv_matrix', {'vprops': {'fmt': 'csv'}}))]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=False)
        yield alt, g
