#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Bighorn sheep (1984)"
description = """Dominance interactions among a group of female bighorn sheep (Ovis canadensis) from the National Bison Range in western Montana USA, over a 27 month period ending in 1984. Edge weights represent the frequency of interaction. Metadata gives the sheep ages, roughly.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Animal', 'Weighted', 'Metadata']
url = 'http://konect.cc/networks/moreno_sheep'
citation = [('C. C. Hass. "Social status in female bighorn sheep (Ovis canadensis): Expression, development and reproductive correlates." J. of Zoology 225(3), 509-523 (1991)', 'https://doi.org/10.1111/j.1469-7998.1991.tb03832.x')]
icon_hash = '5734a190461efe0c7a678332'
upstream_prefix = 'http://konect.cc/files'
files = [('download.tsv.moreno_sheep.tar.bz2', None, 'konect')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=True)
        yield alt, g
