#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Moreno's sociograms (1934)"
description = """Relationships between pupils in a classroom. A directed edge exists if the source wants to sit next to the target. Each child can only choose two others."""
tags = ['Social', 'Offline', 'Weighted']
url = 'https://github.com/grandjeanmartin/sociograms'
citation = [('Jacob Levy Moreno, “Who Shall Survive? A New Approach to the Problem of Human Interrelations”, Washington D.C.: Nervous and Mental Disease Publishing Co.', 'https://doi.org/10.1037/10648-000'),
            ("Martin Grandjean, “Moreno's Sociograms” (2018)",'https://doi.org/10.5281/zenodo.1998343')]
icon_hash = None
upstream_license = ("CC BY 4.0", "https://creativecommons.org/licenses/by/4.0/")
upstream_prefix = 'https://raw.githubusercontent.com/grandjeanmartin/sociograms/master/DATA'
files = []
for i in range(1, 9):
    files += [("Sociogram%d.csv" % i, "grade_%d" % i, None)]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "r")) for fn in fnames]
            g = load_graph_from_csv(fs[0], directed=True, skip_first=True,
                                    csv_options=dict(delimiter=";"))
        yield alt, g
