#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Moviegalaxies, movies 410-466 (2018)"
description = """Social graphs for over 700 movies from the moviegalaxies.com website. Each node represents a character in a movie and each edge is a same-scene appearance between two characters in that movie. The weight gives the number of same-scene appearances. Networks are extracted from movie scripts automatically.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Fictional', 'Weighted']
url = 'https://dataverse.harvard.edu/dataset.xhtml?persistentId=doi:10.7910/DVN/T4HBA3'
citation = [('J. Kaminski et al., "Moviegalaxies - Social Networks in Movies." https://doi.org/10.7910/DVN/T4HBA3, Harvard Dataverse, V3 (2018)', 'https://doi.org/10.7910/DVN/T4HBA3')]
icon_hash = '5b634d77dfd5c2fc3b07984a'
upstream_prefix = 'https://dataverse.harvard.edu/api/access/datafile/:persistentId?persistentId=doi:10.7910/DVN/T4HBA3'
files = [((f"BIOFH6:zip:gexf/{i}.gexf", "NGCUG9"), f"{i}", "gexf") for i in range(1, 915) if
         i not in set([4, 12, 16, 18, 20, 29, 35, 37, 46, 53, 55, 56, 75, 77,
                       78, 79, 90, 94, 95, 96, 105, 121, 140, 156, 160, 168, 172, 181, 188,
                       196, 202, 203, 207, 215, 219, 228, 230, 233, 237, 245, 259, 267, 270,
                       275, 277, 284, 285, 312, 342, 345, 353, 360, 365, 367, 380, 381, 382,
                       390, 392, 425, 428, 431, 440, 441, 448, 463, 473, 479, 480, 492, 493,
                       502, 504, 514, 522, 540, 546, 554, 557, 561, 563, 568, 574, 576, 585,
                       588, 589, 590, 596, 597, 598, 604, 612, 613, 614, 617, 626, 627, 639,
                       646, 654, 663, 674, 676, 680, 681, 684, 690, 702, 709, 711, 722, 726,
                       736, 752, 759, 763, 776, 778, 789, 795, 796, 807, 813, 823, 838, 842,
                       845, 856, 864, 866, 868, 882, 886, 890, 894, 897, 898, 900, 903, 909])]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    gprops = None
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph([fs[0]], fmt, directed=False)
            g.gp.clear()
            p = g.vp["_graphml_vertex_id"]
            del g.vp["_graphml_vertex_id"]
            g.vp.vid = p
            del g.ep["_graphml_edge_id"]

            for p in ["Betweenness Centrality", "Closeness Centrality",
                      "Component ID", "Eccentricity", "Modularity Class",
                      "Degree"]:
                del g.vp[p]

            if gprops is None:
                gprops = {}
                lines = fs[1].read().decode("utf8").splitlines()
                for line in lines[1:]:
                    vals = line.split("\t")
                    gprops[int(vals[0])] = vals[1:5]
            g.gp.movie_title = g.new_gp("string", gprops[int(alt)][0])
            g.gp.imdb_id = g.new_gp("string", gprops[int(alt)][1])
            g.gp.release_date = g.new_gp("string", gprops[int(alt)][2])
            g.gp.slug = g.new_gp("string", gprops[int(alt)][3])

        yield alt, g
