#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "MovieLens 100K (1998)"
description = """Three bipartite networks that make up the MovieLens 100K Dataset, a stable benchmark dataset of 100,000 ratings from 1000 users on 1700 movies. These data capture the tag-movie, user-movie, and user-tag networks. (Also available from MovieLens are 1M, 10M and 20M folksonomy datasets.)[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Informational', 'Folksonomy', 'Unweighted', 'Multigraph', 'Timestamps']
url = 'http://konect.cc/networks/movielens-10m_ti'
citation = [('GroupLens Research, "MovieLens data sets."', 'http://grouplens.org/datasets/movielens/')]
icon_hash = '5759d552bd3e93b53c695600'
upstream_prefix = 'http://konect.cc/files'
files = [('download.tsv.movielens-10m_ti.tar.bz2', None, 'konect')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=False)
        yield alt, g
