#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "November17 members (2009)"
description = """A network representing connections among members of the November 17 (N17) Greek terrorist group. Nodes are members, and an edge exists if two members have some connection in the past. Metadata include role, function, resources. Some attributes are missing.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Offline', 'Unweighted', 'Metadata']
url = 'https://sites.google.com/site/ucinetsoftware/datasets/covert-networks/rhodesbombing'
citation = [('C. J. Rhodes and P. Jones, "Inferring missing links in partially observed social networks." Journal of the Operational Research Society 60(10), 1373-1383 (2009)', 'https://doi.org/10.1057/jors.2008.110')]
icon_hash = '59dae547ee01e9ab21aadc66'
upstream_prefix = 'https://28915467-a-62cb3a1a-s-sites.googlegroups.com/site/ucinetsoftware/datasets/covert-networks/rhodesbombing'
files = [(('Rhodes%20Bombing%20CSV.zip:CSV/RHODESBOMBING.csv', 'Rhodes%20Bombing%20CSV.zip:CSV/RHODESBOMBING_ATTR.csv'), None, ('csv_matrix', {'vprops': {'fmt': 'csv'}}))]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=False)
        yield alt, g
