#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Paris Transportation (2016)"
description = """A multiplex transportation network of Ile-de-France, jointly representing the road network, train network, and subway network. Nodes are intersections, rail stations or metro stations. Different modes of transportation are given by different layers. Within-layer edges represent direct transference by a particular mode of transportation, and between-layer edges represent the conjunction of those layers at that node.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Transportation', 'Public Transport', 'Multilayer', 'Unweighted']
url = 'https://github.com/ComplexNetTSP/MultilayerParis'
citation = [('F. Asgari  et al., "CT-Mapper: Mapping sparse multimodal cellular trajectories using a multilayer transportation network." Computer Communications 95, 69-81 (2016)', 'https://doi.org/10.1016/j.comcom.2016.04.014')]
icon_hash = '5864391ba411221d0e7c3e5d'
ustream_license = None
upstream_prefix = 'https://raw.githubusercontent.com/ComplexNetTSP/MultilayerParis/master/graphml'
files = [('multigraph.graphml', None, 'graphml')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=True)
        yield alt, g
