#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Multilayer physicist collaborations (2015)"
description = """Two multiplex networks of coauthorships among  the Pierre Auger Collaboration of physicists (2010-2012) and among researchers who have posted preprints on arXiv.org (all papers up to May 2014). Layers represent different categories of publication, and an edge's weight indicates the number of reports written by the authors. These layers are one-mode projections from the underlying author-paper bipartite network[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Collaboration', 'Weighted', 'Multilayer', 'Projection']
url = 'https://manliodedomenico.com/data.php'
citation = [('M. De Domenico et al., "Identifying modular flows on multilayer networks reveals highly overlapping organization in interconnected systems." Physical Review X 5(1), 011027 (2015).', 'https://arxiv.org/abs/1408.2925')]
icon_hash = '58a4c4caa411221d0e7c67e5'
upstream_license = ("Open Data Commons Open Database License (ODbL)",
                    "https://opendatacommons.org/licenses/odbl/")
upstream_prefix = 'https://manliodedomenico.com/data'
files = [('PierreAuger_Multiplex_Coauthorship.zip', 'pierreAuger', 'comunelab'),
         ('arXiv-Netscience_Multiplex_Coauthorship.zip', 'arXiv', 'comunelab')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=False)
        yield alt, g
