#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Pokec online social network (2012)"
description = """The online social network of Pokec, a popular OSN in Slovakia, from 2012. Date covers about 10 years and more than 1.6 million people. Profile data contains gender, age, hobbies, interest, education etc. Profile metadata are in Slovak language. Friendships in Pokec are oriented.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Online', 'Metadata']
url = 'http://snap.stanford.edu/data/soc-pokec.html'
citation = [('L. Takac and M. Zabovsky. "Data Analysis in Public Social Networks." Internat. Sci. Conf. & Internat. Workshop Present Day Trends of Innovations, Lomza, Poland (2012).', 'https://snap.stanford.edu/data/soc-pokec.pdf')]
icon_hash = '56a85c8e26855e083a2f78b3'
ustream_license = None
upstream_prefix = 'http://snap.stanford.edu/data'
files = [('soc-pokec-relationships.txt.gz', None, 'snap')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=True)
        yield alt, g
