#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Political blogs network (2004)"
description = """A directed network of hyperlinks among a large set of U.S. political weblogs from before the 2004 election. Includes blog political affiliation as metadata.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Informational', 'Web graph', 'Unweighted', 'Metadata']
url = 'http://www-personal.umich.edu/~mejn/netdata'
citation = [('L. A. Adamic and N. Glance, "The political blogosphere and the 2004 U.S. election: divided they blog." Proc. 3rd Internat. Workshop on Link Discovery (LinkKDD), 36-43 (2005).', 'https://doi.org/10.1145/1134271.1134277')]
icon_hash = '56a85c8e26855e083a2f78a1'
ustream_license = None
upstream_prefix = 'http://www-personal.umich.edu/~mejn/netdata'
files = [('polblogs.zip:polblogs.gml', None, 'gml')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=True)
        yield alt, g
