#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Python Dependency Network"
description = """Python's package dependency networks. Nodes in the network are Python's packages registered to PyPI and edges are dependencies among packages.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Technological', 'Software', 'Unweighted']
url = 'http://kgullikson88.github.io/blog/pypi-analysis.html'
citation = [('Kevin Gullikson, "Python Dependency Analysis"', 'http://kgullikson88.github.io/blog/pypi-analysis.html')]
icon_hash = '56c53507a6d70217090cdb80'
ustream_license = None
upstream_prefix = 'http://kgullikson88.github.io/blog/Downloads/PypiDependencies'
files = [('requirements.csv', None, 'csv')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "r")) for fn in fnames]

            fs[0].readline()

            g = load_graph_from_csv(fs[0], hashed=True, hash_type="string",
                                    ecols=(2,1), directed=True)
            remove_parallel_edges(g)

        yield alt, g
