#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "User interactions on Q&A websites (2016)"
description = """Networks of interactions among users from four online Q&A sites: Stack Overflow, Math Overflow, Super User, and Ask Ubuntu. A directed edge (i,j)  indicates a user i responded to user j's post. Edges are timestamped. For each Q&A site, four differently defined networks are provided, based on the definition of an edge: (i) a user answered a question, (ii) a user commented on a question, (iii) a user commented on an answer, and (iv) the union of these three types.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Online', 'Unweighted', 'Timestamps']
url = 'http://snap.stanford.edu/data/sx-stackoverflow.html'
citation = [('A. Paranjape, A. R. Benson, & J. Leskovec, "Motifs in Temporal Networks". In Proceedings of the Tenth ACM International Conference on Web Search and Data Mining (WSDM ’17). Association for Computing Machinery, New York, NY, USA, 601–610. (2017)', 'https://doi.org/10.1145/3018661.3018731')]
icon_hash = '586eac70a411221d0e7c5bda'
ustream_license = None
upstream_prefix = 'https://snap.stanford.edu/data'
files = [('sx-stackoverflow.txt.gz', 'stackoverflow_all', None),
         ('sx-stackoverflow-a2q.txt.gz', 'stackoverflow_a2q', None),
         ('sx-stackoverflow-c2q.txt.gz', 'stackoverflow_c2q', None),
         ('sx-stackoverflow-c2a.txt.gz', 'stackoverflow_c2a', None),
         ('sx-mathoverflow.txt.gz', 'mathoverflow_all', None),
         ('sx-mathoverflow-a2q.txt.gz', 'mathoverflow_a2q', None),
         ('sx-mathoverflow-c2q.txt.gz', 'mathoverflow_c2q', None),
         ('sx-mathoverflow-c2a.txt.gz', 'mathoverflow_c2a', None),
         ('sx-superuser.txt.gz', 'superuser_all', None),
         ('sx-superuser-a2q.txt.gz', 'superuser_a2q', None),
         ('sx-superuser-c2q.txt.gz', 'superuser_c2q', None),
         ('sx-superuser-c2a.txt.gz', 'superuser_c2a', None),
         ('sx-askubuntu.txt.gz', 'askubuntu_all', None),
         ('sx-askubuntu-a2q.txt.gz', 'askubuntu_a2q', None),
         ('sx-askubuntu-c2q.txt.gz', 'askubuntu_c2q', None),
         ('sx-askubuntu-c2a.txt.gz', 'askubuntu_c2a', None)]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
#@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fname, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        with open_upstream_file(name, fname, "r") as f:
            g = Graph()
            g.ep.timestamp = time = g.new_ep("int64_t")
            def get_lines():
                for line in f:
                    vals = [int(x) for x in line.split()]
                    yield vals
            vid = g.add_edge_list(get_lines(), hashed=True, eprops=[time])
            g.vp.vid = vid.copy("int")
        yield alt, g
