#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *
import datetime

title = "Route Views AS graphs (1997-1998)"
description = """733 daily network snapshots denoting BGP traffic among autonomous systems (ASs) on the Internet, from the Oregon Route Views Project, spanning 8 November 1997 to 2 January 2000. Data collected by NLANR/MOAT.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Technological', 'Communication', 'Unweighted', 'Temporal']
url = 'http://snap.stanford.edu/data/as.html'
citation = [('"University of Oregon Route Views Project" (2001)', 'http://www.routeviews.org/')]
icon_hash = '56a85c8e26855e083a2f78be'
ustream_license = None
upstream_prefix = 'https://snap.stanford.edu/data'

files = []

missing = set(['19980207', '19980405', '19980412', '19980522', '19980524',
               '19980628', '19980629', '19980704', '19980707', '19980716',
               '19980913', '19990113', '19990121', '19990126', '19990404',
               '19990410', '19990520', '19990623', '19990712', '19990725',
               '19990803', '19991012', '19991014', '19991015', '19991020',
               '19991021', '19991022', '19991023', '19991024', '19991025',
               '19991029', '19991030', '19991101', '19991102', '19991103',
               '19991104', '19991106', '19991107', '19991117', '19991119',
               '19991120', '19991123', '19991124', '19991125', '19991126',
               '19991127', '19991128', '19991129', '19991130', '19991201',
               '19991202', '19991203', '19991207'])

for d in range(0, 733 + len(missing)):
    date = datetime.date(year=1997, day=8, month=11) + datetime.timedelta(days=d)
    s = "%d%02d%02d" % (date.year, date.month, date.day)
    if s in missing:
        continue
    files.append((f"as-733.tar.gz:as{s}.txt" , s, "snap"))

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=False)
            remove_parallel_edges(g)
            g.vp.as_id = g.vertex_index.copy()
            vs = [v for v in g.vertices() if v.in_degree() + v.out_degree() == 0]
            g.remove_vertex(vs, fast=True)
        yield alt, g
