#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Location-based social networks"
description = """Two location-based online social networks, where nodes are accounts and edges are declared friendships. Networks includes checkins by these users.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Online', 'Spatial']
url = 'http://snap.stanford.edu/data/loc-gowalla.html'
citation = [('E. Cho, S. A. Myers, and J. Leskovec, "Friendship and mobility: user movement in location-based social networks." Proc. 17th Internat. Conf. on Knowledge Discovery and Data Mining (KDD), 1082-1090 (2011).', 'https://doi.org/10.1145/2020408.2020579')]
icon_hash = '56a85c8e26855e083a2f78c1'
ustream_license = None
upstream_prefix = 'https://snap.stanford.edu/data'
files = [('loc-gowalla_edges.txt.gz', 'gowalla', 'snap'),
         ('loc-brightkite_edges.txt.gz', 'brightkite', 'snap')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=False)
        yield alt, g
