#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "9-11 terrorist network"
description = """Network of individuals and their known social associations, centered around the hijackers that carried out the September 11th, 2001 terrorist attacks. Associations extracted after-the-fact from public data. Metadata labels say which plane a person was on, if any, on 9/11.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Offline', 'Unweighted', 'Metadata']
url = 'https://aaronclauset.github.io/datacode.htm'
citation = [('V. Krebs, "Mapping networks of terrorist cells." Connections 24, 43-52 (2002).', 'https://doi.org/10.5210/fm.v7i4.941')]
icon_hash = '56a85c8e26855e083a2f7924'
ustream_license = None
upstream_prefix = 'https://aaronclauset.github.io/hierarchy'
files = [(('terrorists.zip:terrorists/terrorist.pairs',
           'terrorists.zip:terrorists/terrorist.names',
           'terrorists.zip:terrorists/terrorist.groups'), None, 'loadtxt')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph([fs[0]], fmt, directed=False)

            g.vp.id = g.vp.name
            del g.vp["name"]

            vs = {g.vp.id[v] : v for v in g.vertices()}

            g.vp.name = g.new_vp("string")
            f = io.TextIOWrapper(fs[1])
            for line in f:
                vals = line.split()
                v = vs[vals[0]]
                g.vp.name[v] = " ".join(vals[1:])

            g.vp.group = g.new_vp("int")
            f = io.TextIOWrapper(fs[2])
            for line in f:
                vals = line.split()
                v = vs[vals[0]]
                try:
                    g.vp.group[v] = int(vals[1])
                except ValueError:
                    # crap in data!
                    g.vp.group[v] = 4

            remove_parallel_edges(g)

        yield alt, g
