#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Twitter 15-M movement (2011)"
description = """A network representing follower-following relations among Twitter users associated with the 15-M Movement or Anti-austerity movement in Spain, in the period April-May 2011. Metadata include hashtags in the tweets.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Online', 'Unweighted', 'Metadata']
url = 'http://www.plexmath.eu/?page_id=320'
citation = [('S. González-Bailón, et al. "The dynamics of protest recruitment through an online network." Scientific Reports 1, 197 (2011)', 'https://doi.org/10.1038/srep00197')]
icon_hash = '595a92c44ed8f1bb6022ef56'
ustream_license = None
upstream_prefix = 'http://cosnet.bifi.es/wp-content/uploads//2013/03'
files = [('15m.zip:15m/15m_follower.net', None, 'pajek')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=True)
        yield alt, g
