#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Twitter graph (2009)"
description = """A large (possibly complete) snapshot of Twitter in 2009, represented as an anonymized network of accounts and their follow links.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Online', 'Unweighted']
url = 'http://twitter.mpi-sws.org/'
citation = [('M. Cha, H. Haddadi, F. Benevenuto, and K. P. Gummadi, "Measuring User Influence in Twitter: The Million Follower Fallacy" Proc. Internat. AAAI Conf. on Weblogs and Social Media (ICWSM), 10-17 (2010).', 'https://doi.org/10.1145/2897659.2897663')]
icon_hash = '56a85c8e26855e083a2f78d4'
ustream_license = None
upstream_prefix = 'http://twitter.mpi-sws.org/'
files = [('links-anon.txt.gz', None, None)]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "r")) for fn in fnames]
            def edges():
                for line in fs[0]:
                    vs = line.split()
                    yield int(vs[0]), int(vs[1])
            g = Graph()
            g.vp.name = g.add_edge_list(edges(), hashed=True, hash_type="int")
        yield alt, g
