#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Twitter, 5 events (2013-2014)"
description = """Various multiplex networks of retweets, mentions, and replies among Twitter users during specific events or occasions in 2013 and 2014.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Online', 'Multilayer', 'Unweighted']
url = 'https://manliodedomenico.com/data.php'
citation = [('E. Omodei, M. De Domenico, and A. Arenas. "Characterizing interactions in online social networks during exceptional events." Front. Phys. 3, 59 (2015)', 'https://doi.org/10.3389/fphy.2015.00059')]
icon_hash = '56ce1af2a6d70217090cdb89'
upstream_license = ("Open Data Commons Open Database License (ODbL)",
                    "https://opendatacommons.org/licenses/odbl/")
upstream_prefix = 'https://manliodedomenico.com/data'
files = [('NYClimateMarch2014_Multiplex_Social.zip', 'NYClimateMarch2014', 'comunelab'),
         ('Cannes2013_Multiplex_Social.zip', 'Cannes2013', 'comunelab'),
         ('MoscowAthletics2013_Multiplex_Social.zip','MoscowAthletics2013', 'comunelab'),
         ('MLKing2013_Multiplex_Social.zip', 'MLKing2013', 'comunelab'),
         ('ObamaInIsrael2013_Multiplex_Social.zip', 'ObamaInIsrael2013', 'comunelab')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=True)
        yield alt, g
