#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Twitter sample (2014)"
description = """A sample of the Twitter follower network in 2012, obtained by crawling follower links outward breadth- or depth-first from an arbitrary set of seed profiles. Nodes are twitter accounts, and edges represent the directed following relationship.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Online', 'Unweighted']
url = 'http://data4good.cs.washington.edu/index.html'
citation = [('D. Kagan, M. Fire, and Y. Elovici, "Unsupervised Anomalous Vertices Detection Utilizing Link Prediction Algorithms", Preprint, arXiv:1610.07525 (2017)', 'https://arxiv.org/abs/1610.07525')]
icon_hash = '5b3ff17f10471f300af5092d'
ustream_license = None
upstream_prefix = 'http://proj.ise.bgu.ac.il/sns/datasets'
files = [('twitter.csv.gz', None, None)]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fname, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        with open_upstream_file(name, fname, "r") as f:
            g = Graph()
            next(f)
            def get_lines():
                for line in f:
                    yield [int(x) - 1 for x in line.split(",")]
            g.add_edge_list(get_lines(), hashed=False)
        yield alt, g
