#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Twitter social graph"
description = """This network contains the social graph of twitter, where a directed edge (i,j) means that user i follows user j.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Online', 'Unweighted']
url = 'https://an.kaist.ac.kr/traces/WWW2010.html'
citation = [('Haewoon Kwak, Changhyun Lee, Hosung Park, and Sue Moon. 2010. "What is Twitter, a social network or a news media?" In Proceedings of the 19th international conference on World wide web (WWW ’10). Association for Computing Machinery, New York, NY, USA, 591–600.','https://doi.org/10.1145/1772690.1772751')]
icon_hash = '595b194b549f067e0263b535'
ustream_license = None
upstream_prefix = 'http://an.kaist.ac.kr/~haewoon/release/twitter_social_graph'
files = [("twitter_rv.zip:twitter_rv.net", None, None)]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fname, alt, fmt in files:
        with open_upstream_file(name, fname, "r") as f:
            def get_line():
                for line in f:
                    vals = [int(x) for x in line.split()]
                    vals[0], vals[1] = vals[1], vals[0]
                    yield vals
            g = Graph(directed=True)
            g.vp.name = g.add_edge_list(get_line(), hashed=True,
                                        hash_type="int")
        yield alt, g
