#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Ugandan village networks (2013)"
description = """Complete friendship and health advice social networks among households in 17 rural villages bordering Lake Victoria in Mayuge District, Uganda in 2013. Nodes are households and edges represent either a close friendship or a trusted health advisor connection, obtained via a name generator questionnaire.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Offline', 'Unweighted', 'Multilayer']
url = 'https://www.repository.cam.ac.uk/handle/1810/270256?show=full'
citation = [('G. F. Chami et al., "Social network fragmentation and community health." Proc. Natl. Acad. Sci. USA 114(36), E7425–E7431 (2017)', 'https://doi.org/10.1073/pnas.1700166114')]
icon_hash = '5b2c7544eb70bccf32add88d'
ustream_license = None
upstream_prefix = 'https://www.repository.cam.ac.uk/bitstream/handle/1810/270256'
files = \
    [(f"Uganda%20Network%20Edgelists%202013.zip:Uganda Network Edgelists 2013/friendship/{vil}", f"friendship-{vil}", "csv") for vil in range(1, 18)] + \
    [(f"Uganda%20Network%20Edgelists%202013.zip:Uganda Network Edgelists 2013/health_advice/{vil}", f"health-advice_{vil}", "csv") for vil in range(1, 18)]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=False)
        yield alt, g
