#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Urban street networks (2017)"
description = """20 urban street networks, corresponding to 1-square-mile maps of 20 cities around the world.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Transportation', 'Roads', 'Unweighted', 'Metadata']
url = 'https://www.complex-networks.net/datasets.html#chap8'
citation = [('P. Crucitti, V. Latora, and S. Porta. "Centrality measures in spatial networks of urban streets". Phys. Rev. E 73 (2006), 036125', 'https://doi.org/10.1103/PhysRevE.73.036125'),
            ('V. Latora, V. Nicosia, G. Russo, "Complex Networks: Principles, Methods and Applications", Cambridge University Press (2017)', "https://doi.org/10.1017/9781316216002") ]
icon_hash = None
ustream_license = None
upstream_prefix = 'https://www.complex-networks.net/datasets/'

cities = ['ahmedabad', 'barcelona', 'bologna', 'brasilia', 'cairo', 'irvine1',
          'irvine2', 'london', 'los-angeles', 'new-delhi', 'new-york', 'paris',
          'richmond', 'san-francisco', 'savannah', 'seoul', 'venice', 'vienna',
          'walnut-creek', 'washington']

files = [(f'cities.zip:cities/{city}_edge_info.txt', city, None) for city in cities]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "r")) for fn in fnames]
            g = Graph(directed=False)
            g.vp.pos = g.new_vp("vector<double>")
            g.ep.length = g.new_ep("double")
            for line in fs[0]:
                vals = [float(x) for x in line.split()]
                edge_num, node_1, X_1, Y_1, node_2, X_2, Y_2, length = vals
                if g.num_vertices() <= max(node_1, node_2):
                    g.add_vertex(int(max(node_1, node_2)) - g.num_vertices() + 1)
                e = g.add_edge(int(node_1), int(node_2))
                g.ep.length[e] = length
                g.vp.pos[int(node_1)] = [X_1, Y_1]
                g.vp.pos[int(node_2)] = [X_2, Y_2]
        yield alt, g
