#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from openpyxl import load_workbook
from .. import *

title = "US Congressional co-sponsorship (1973-2016)"
description = """Two temporal networks of bill co-sponsorship tendencies among US Congresspeople, from 1973 (93rd Congress) to 2016 (114th Congress). Edges are signed, indicating the presence of a significant tendency to co-sponsor, or tendency to not co-sponsor, bills. Two networks per year, one for each chamber (House, Senate). Each file contains the signed network for a chamber of congress (H = House, S = Senate) in one session (e.g. 93 = 93rd session of congress).[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project.""" 
tags = ['Social', 'Political', 'Signed', 'Temporal']
url = 'https://doi.org/10.6084/m9.figshare.8096429'
citation = [('Z. P. Neal, "A sign of the times? Weak and strong polarization in the U.S. Congress, 1973-2016." Social Networks 60, 103-112 (2020)', 'https://doi.org/10.1016/j.socnet.2018.07.007'),
            ('Neal, Z. P. (2014). "The backbone of bipartite projections: Inferring relationships from co-authorship, co-sponsorship, co-attendance and other co-behaviors." Social Networks, 39, 84-97.', 'https://doi.org/10.1016/j.socnet.2014.06.001')]
icon_hash = '5e252c0878691ca4060b74bd'
upstream_prefix = 'https://ndownloader.figshare.com/files/'
files = [('20758701', f'H{d}', None) for d in range(93, 115)] + \
    [('20758701', f'S{d}', None) for d in range(93, 115)]
upstream_license = "CC-BY 4.0"

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
#@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    wb = None
    for fname, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if wb is None:
            with open_upstream_file(name, fname, "rb") as f:
                wb = load_workbook(f)

        g = Graph(directed=False)

        g.vp.name = g.new_vp("string")
        g.ep.weight = g.new_ep("int16_t")

        for i, row in enumerate(wb[alt].values):
            if i == 0:
                g.add_vertex(len(row)-1)
            g.vp.name[g.vertex(0)] = row[0]
            for j, val in enumerate(row[1:]):
                x = int(val)
                if x == 0 or i > j:
                    continue
                e = g.add_edge(i, j)
                g.ep.weight[e] = x

        yield alt, g
