#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "WebKB graphs (1998)"
description = """Web graphs crawled from four Computer Science departments in 1998, with each page manually classified into one of 7 categories: course, department, faculty, project, staff, student, or other. All graphs included in a single .zip; also included are 'co-citation' graphs, which links i and j if they both point to some k. Edge weights count the number of links from i to j.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Informational', 'Web graph', 'Weighted', 'Metadata']
url = 'http://netkit-srl.sourceforge.net/data.html'
citation = [('S. Slattery & M. Craven, "Combining Statistical and Relational Methods for Learning in Hypertext Domains." In Proc. 8th International Conf. on Inductive Logic Programming, 38-52 (1998)', 'https://doi.org/10.1007/bfb0027309')]
icon_hash = '57574842bd3e93b53c695555'
upstream_prefix = 'http://netkit-srl.sourceforge.net/data'
files = [((f'webkb.zip:webkb_{name}/WebKB-{name.replace("_","-")}.rn',
           f'webkb.zip:webkb_{name}/WebKB-{name.replace("_","-")}.csv'),
          f'webkb_{name}', ('csv', {'props': ['weight'],
                                    'vprops': {'fmt': 'csv'}}))
         for name in ["wisconsin_link1", "wisconsin_cocite", "washington_link1",
                      "washington_cocite", "cornell_link1", "cornell_cocite",
                      "texas_link1", "texas_cocite"]]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed="cocite" not in fnames[0])
        yield alt, g
