#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Wikipedia link dynamics (2011)"
description = """Six networks of the evolving hyperlink structure among wikipedia articles, for simple English (en), German (de), Dutch (nl), Polish (pl), Italian (it), French (fr), taken in August 2011. Each edge is timestamped, and an edge (i,j) indicates that article i hyperlinks to j. The edge sign indicates the addition (+1) or deletion (-1) of that link at the specified time.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Informational', 'Web graph', 'Unweighted', 'Timestamps']
url = 'http://konect.cc/networks/link-dynamic-simplewiki'
citation = [('J. Preusse et al.,  "Structural Dynamics of Knowledge Networks." Proc. Int. Conf. on the Web and Social Media (ICWSM 2013).', 'http://www.mthimm.de/pub/2013/Preusse_2013.pdf')]
icon_hash = '57ec17198cf714f319c38eb6'
upstream_prefix = 'http://konect.cc/files'
files = [('download.tsv.link-dynamic-simplewiki.tar.bz2', None, 'konect')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=True)
        yield alt, g
