#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Wikipedia talk networks"
description = """Interactions among users of 10 language-specific Wikipedias: Arabic, Chinese, Dutch, English, French, German, Italian, Portuguese, Russian, and Spanish. Nodes are registered wiki editors, and an edge represents a user i having written a message on user j's talk page. Edges are timestamped. The precise dates of the snapshots are uncertain.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Communication', 'Unweighted', 'Multigraph', 'Timestamps']
url = 'http://konect.cc/networks/wiki_talk_ar'
citation = [('J. Kunegis "Wikipedia talk networks" KONECT (2016)', 'https://doi.org/10.1145/2487788.2488173')]
icon_hash = '57575c6dbd3e93b53c69557f'
upstream_prefix = 'http://konect.cc/files'
files = [('download.tsv.wiki_talk_ar.tar.bz2', 'ar', 'konect'), ('download.tsv.wiki_talk_bn.tar.bz2', 'bn', 'konect'), ('download.tsv.wiki_talk_br.tar.bz2', 'br', 'konect'), ('download.tsv.wiki_talk_ca.tar.bz2', 'ca', 'konect'), ('download.tsv.wiki_talk_cy.tar.bz2', 'cy', 'konect'), ('download.tsv.wiki_talk_de.tar.bz2', 'de', 'konect'), ('download.tsv.wiki_talk_el.tar.bz2', 'el', 'konect'), ('download.tsv.wiki_talk_en.tar.bz2', 'en', 'konect'), ('download.tsv.wiki_talk_eo.tar.bz2', 'eo', 'konect'), ('download.tsv.wiki_talk_es.tar.bz2', 'es', 'konect'), ('download.tsv.wiki_talk_eu.tar.bz2', 'eu', 'konect'), ('download.tsv.wiki_talk_fr.tar.bz2', 'fr', 'konect'), ('download.tsv.wiki_talk_gl.tar.bz2', 'gl', 'konect'), ('download.tsv.wiki_talk_ht.tar.bz2', 'ht', 'konect'), ('download.tsv.wiki_talk_it.tar.bz2', 'it', 'konect'), ('download.tsv.wiki_talk_ja.tar.bz2', 'ja', 'konect'), ('download.tsv.wiki_talk_lv.tar.bz2', 'lv', 'konect'), ('download.tsv.wiki_talk_nds.tar.bz2', 'nds', 'konect'), ('download.tsv.wiki_talk_nl.tar.bz2', 'nl', 'konect'), ('download.tsv.wiki_talk_oc.tar.bz2', 'oc', 'konect'), ('download.tsv.wiki_talk_pl.tar.bz2', 'pl', 'konect'), ('download.tsv.wiki_talk_pt.tar.bz2', 'pt', 'konect'), ('download.tsv.wiki_talk_ru.tar.bz2', 'ru', 'konect'), ('download.tsv.wiki_talk_sk.tar.bz2', 'sk', 'konect'), ('download.tsv.wiki_talk_sr.tar.bz2', 'sr', 'konect'), ('download.tsv.wiki_talk_sv.tar.bz2', 'sv', 'konect'), ('download.tsv.wiki_talk_vi.tar.bz2', 'vi', 'konect'), ('download.tsv.wiki_talk_zh.tar.bz2', 'zh', 'konect')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=True)
        yield alt, g
