#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "en-Wikipedia talk network (2008)"
description = """Nodes in the network represent (English) Wikipedia users and a directed edge from node i to node j represents that user i at least once edited a talk page of user j. The network contains all users and posts from the inception of Wikipedia till January 2008.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Communication', 'Unweighted']
url = 'http://snap.stanford.edu/data/wiki-Talk.html'
citation = [('J. Leskovec, D. Huttenlocher, and J. Kleinberg, "Signed networks in social media." Proc. Conf. on Human Factors in Computing Sys. (CHI), 1361-1370 (2010).', 'https://doi.org/10.1145/1753326.1753532')]
icon_hash = '56a85c8e26855e083a2f78b7'
upstream_prefix = 'https://snap.stanford.edu/data'
files = [('wiki-Talk.txt.gz', None, 'snap')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=True)
        yield alt, g
