#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "en-Wikipedia links (2007)"
description = """The network of hyperlinks among English wikipedia pages, in 2007. An edge (i,j) indicates that article i hyperlinks to article j, and each edge is timestamped with its creation.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Informational', 'Web graph', 'Unweighted', 'Timestamps']
url = 'http://konect.cc/networks/wikipedia-growth'
citation = [('A. Mislove, "Online social networks: measurement, analysis, and applications to distributed information systems.” PhD Thesis. Rice University. (2009).', 'http://www.ccs.neu.edu/home/amislove/publications/SocialNetworks-Thesis.pdf')]
icon_hash = '57ec19aa8cf714f319c38ebf'
upstream_prefix = 'http://konect.cc/files'
files = [('download.tsv.wikipedia-growth.tar.bz2', None, 'konect')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=True)
        yield alt, g
