#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Wikipedia links (2016)"
description = """Networks of hyperlinks among articles on Wikipedia, for all available languages. A directed edge (i,j) indicates that article i hyperlinks to j.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Informational', 'Web graph', 'Unweighted']
url = 'http://konect.cc/networks/wikipedia_link_en'
citation = [('J. Kunegis, "Wikipedia links." KONECT - The Koblenz Network Collection (2016).', 'https://doi.org/10.1145/2487788.2488173')]
icon_hash = '57f2d9bd8cf714f319c39129'
upstream_prefix = 'http://konect.cc/files'
files = [(f'download.tsv.wikipedia_link_{la}.tar.bz2', f"{la}", 'konect') for la
         in ["af", "als", "am", "an", "ar", "arz", "as", "ast", "az", "ba",
             "bar", "bat_smg", "bcl", "be", "be_x_old", "bg", "bh", "bn", "bpy",
             "br", "bs", "bug", "ca", "cdo", "ce", "ceb", "ckb", "co", "crh", "cs",
             "csb", "cv", "cy", "da", "de", "diq", "dv", "el", "eml", "en", "eo",
             "es", "et", "eu", "fa", "fi", "fiu_vro", "fo", "fr", "fy", "ga",
             "gag", "gan", "gd", "gl", "glk", "gu", "gv", "hak", "he", "hi", "hif",
             "hr", "hsb", "ht", "hu", "hy", "ia", "id", "ilo", "io", "is", "it",
             "ja", "jv", "ka", "kk", "kn", "ko", "ku", "kv", "ky", "la", "lb",
             "lez", "li", "lmo", "lo", "lt", "lv", "map_bms", "mg", "mhr", "mi",
             "min", "mk", "ml", "mn", "mr", "ms", "my", "myv", "mzn", "nah", "nap",
             "nds", "nds_nl", "ne", "new", "nl", "nn", "no", "nso", "oc", "or",
             "os", "pa", "pam", "pl", "pms", "pnb", "ps", "pt", "qu", "ro",
             "roa_tara", "ru", "rue", "sa", "sah", "scn", "sco", "se", "sh", "si",
             "simple", "sk", "sl", "so", "sq", "sr", "su", "sv", "sw", "ta", "te",
             "tg", "th", "tk", "tl", "tr", "tt", "uk", "ur", "uz", "vec", "vi",
             "vls", "vo", "wa", "war", "xal", "xmf", "yi", "yo", "zh",
             "zh_min_nan", "zh_yue"]]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=True)
        yield alt, g
