#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "WikiTree genealogies (1400-2012)"
description = """A multigraph network representing child-parent connections among family members, collected in 2012 from WikiTree, an online genealogical website with 13+ million profiles. Nodes are people born between 1400 and 2012, and a directed edge connects a parent to their child.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Social', 'Relationships', 'Unweighted', 'Multigraph']
url = 'https://data4goodlab.github.io/MichaelFire/#section3'
citation = [('M. Fire, & Y. Elovici, "Data mining of online genealogy datasets for revealing lifespan patterns in human population." ACM Transactions on Intelligent Systems and Technology (TIST) 6(2), 28 (2015)', 'https://arxiv.org/abs/1311.4276')]
icon_hash = '59fe986aee01e9ab21ac7fcc'
ustream_license = None
upstream_prefix = 'https://data4goodlab.github.io/MichaelFire/datasets'
files = [('wikitree.zip:wikitree/wikitree_anon.csv', None,
          ("csv", dict(props=["type"])))]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=True)
        yield alt, g
