#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Word Adjacency Networks"
description = """Directed Networks of word adjacency in texts of several languages including English, French, Spanish and Japanese[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Informational', 'Language', 'Unweighted']
url = 'https://doi.org/10.1126/science.1089167'
citation = [('R. Milo. et al., "Superfamilies of Evolved and Designed Networks." Science (2004)', 'https://doi.org/10.1126/science.1089167')]
icon_hash = '5723b74b461efe0c7a675bcd'
ustream_license = None
upstream_prefix = 'https://www.weizmann.ac.il/mcb/UriAlon/sites/mcb.UriAlon/files/uploads/CollectionsOfComplexNetwroks'
files = [('darwinbookinter_st.txt', 'darwin', 'loadtxt'),
         ('frenchbookinter_st.txt', 'french', 'loadtxt'),
         ('spanishbookinter_st.txt', 'spanish', 'loadtxt'),
         ('japanesebookinter_st.txt', 'japanese', 'loadtxt')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=True)
            del g.ep["p0"]
        yield alt, g
