#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Edinburgh word associations"
description = """A network of word associations showing the count of such associations as collected from subjects, from the Edinburgh Associative Thesaurus (EAT). Each node represents a word, and a directed edge (i, j) denotes that word i was used as a stimulus to which word j was given as a response. Multiple edges are allowed.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Informational', 'Language', 'Unweighted', 'Multigraph']
url = 'http://konect.cc/networks/eat'
citation = [('G. Kiss et al. "An associative thesaurus of English and its computer analysis." The computer and literary studies (1973): 153-165.', 'http://www.eat.rl.ac.uk/Kiss_EAT_Chapter_1973.pdf')]
icon_hash = '580655df8cf714f319c3be8b'
upstream_prefix = 'http://konect.cc/files'
files = [('download.tsv.eat.tar.bz2', None, 'konect')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=True)
        yield alt, g
