#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Yahoo song ratings (2011)"
description = """A bipartite network of users and songs they rated, as used in the 2011 KDD Cup and extracted from Yahoo! Music. Edge weights denote a rating scaled from 0 to 100. More information about this data set is available at http://konect.cc/networks/yahoo-song[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Economic', 'Preferences', 'Timestamps', 'Weighted']
url = 'http://konect.cc/networks/yahoo-song'
citation = [('G. Dror et al. "The Yahoo! Music Dataset and KDD-Cup\'11." KDD Cup (2012).', 'http://www.jmlr.org/proceedings/papers/v18/dror12a/dror12a.pdf')]
icon_hash = '58879753a411221d0e7c6789'
upstream_prefix = 'http://konect.cc/files'
files = [('download.tsv.yahoo-song.tar.bz2', None, 'konect')]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=True)
        yield alt, g
