#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

import os
import io
import pickle
from googleapiclient.http import MediaIoBaseDownload
from google_auth_oauthlib.flow import InstalledAppFlow
from googleapiclient.discovery import build
from tempfile import TemporaryFile

if os.path.exists("gdrive_token.pickle"):
    with open('gdrive_token.pickle', 'rb') as f:
        creds = pickle.load(f)
else:
    SCOPES = ["https://www.googleapis.com/auth/drive.readonly"]
    flow = InstalledAppFlow.from_client_secrets_file('credentials.json', SCOPES)
    creds = flow.run_local_server(port=8080, success_message='success')
    with open('gdrive_token.pickle', 'wb') as f:
        pickle.dump(creds, f)

gdrive_service = None

def save_gdrive_file(file_id, fobj):
    global gdrive_service, creds
    if gdrive_service is None:
        gdrive_service = build('drive', 'v3', credentials=creds)
    request = gdrive_service.files().get_media(fileId=file_id)

    check = False
    with TemporaryFile(mode="w+b") as tmp:
        if fobj is None:
            check = True
            fobj = tmp
        downloader = MediaIoBaseDownload(fobj, request,
                                         chunksize=104857600 if not check else 1)
        done = False
        while not done:
            status, done = downloader.next_chunk()
            if check:
                return
