#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

import pkgutil

import sys
import os
import gc

from graph_tool.all import *

import process_entry
from analyze import analyze_entries
from convert import convert_entry

from locks import acquire_lock

def update_props(entry, ret_all=False):
    for alt, g in entry.parse(lazy=True, cache_only=True):
        vprops = entry.analyses[alt].get("vertex_properties", [])
        vprops = [x[0] for x in vprops]
        pos = entry.analyses[alt]["pos"]

        if pos is not None and "_pos" not in vprops:
            g_ = g()
            x = g_.new_vp("double", vals=pos[0])
            y = g_.new_vp("double", vals=pos[1])
            pos = group_vector_property((x,y))
            g_.vp._pos = pos
            g.update(g_)
            yield alt, g
        elif ret_all:
            yield alt, g

if __name__ == "__main__":

    if len(sys.argv) > 1:
        names = sys.argv[1:]
    else:
        names = None

    entries = process_entry.get_entries(names)

    for entry in entries.values():
        with acquire_lock(entry, block=False) as lock:
            if lock is None:
                continue
            print("entry:", entry.name)
            analyze_entries([entry], cache_only=True)
            for alt, g in update_props(entry):
                convert_entry(entry, force=True)
            analyze_entries([entry], cache_only=False,
                            force=["vertex_properties", "edge_properties"])