#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2020-2023 Tiago de Paula Peixoto <tiago@skewed.de>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from .. import *

title = "Metabolic networks from KEGG (2006)"
description = """109 metabolic networks of various species, as extracted from the Kyoto Encyclopedia of Genes and Genomes (KEGG) database in March 2006. Nodes are substances involved in enzymatic reactions present in the organism, and edges represent reactant-product pairs as extracted from the KEGG ligand database and matched against the present enzymes.[^icon]
[^icon]: Description obtained from the [ICON](https://icon.colorado.edu) project."""
tags = ['Biological', 'Metabolic', 'Unweighted']
url = 'http://santafe.edu/~aaronc/data/kegg2006_metabolic.zip'
citation = [('M. Huss & P. Holme, "Currency and commodity metabolites: their identification and relation to the modularity of metabolic networks." IET Syst. Biol. 1(5), 280-285 (2007)', 'https://doi.org/10.1049/iet-syb:20060077')]
icon_hash = '56e99103a6d70217090cde5c'
ustream_license = None
upstream_prefix = 'http://santafe.edu/~aaronc/data'
files = [(f"kegg2006_metabolic.zip:kegg2006_metabolic/links_{d}", d, "loadtxt") for d in
         ['aae', 'afu', 'ana', 'ape', 'atc','ath', 'atu', 'bas', 'bbu', 'bha',
          'bja', 'blo', 'bme', 'bms', 'bsu', 'buc', 'cac', 'ccr', 'cef', 'cel',
          'cgl', 'cje', 'cmu', 'cpa', 'cpe', 'cpj', 'cpn', 'cte', 'ctr', 'dme',
          'dra', 'ecc', 'ece', 'ecj', 'eco', 'ecs', 'fnu', 'hal', 'hin', 'hpj',
          'hpy', 'hsa', 'lil', 'lin', 'lla', 'lmo', 'mac', 'mge', 'mja', 'mka',
          'mle', 'mlo', 'mma', 'mmu', 'mpe', 'mpn', 'mpu', 'mtc', 'mth', 'mtu',
          'nma', 'nme', 'oih', 'pab', 'pae', 'pai', 'pfu', 'pho', 'pmu', 'rco',
          'rno', 'rpr', 'rso', 'sag', 'sam', 'san', 'sau', 'sav', 'sce', 'sco',
          'sfl', 'sme', 'smu', 'son', 'spg', 'spm', 'spn', 'spo', 'spr', 'spy',
          'sso', 'stm', 'sto', 'sty', 'syn', 'tac', 'tel', 'tma', 'tpa', 'tte',
          'tvo', 'uur', 'vch', 'wbr', 'xac', 'xcc', 'xfa', 'ype', 'ypk']]

def fetch_upstream(force=False):
    return fetch_upstream_files(__name__.split(".")[-1], upstream_prefix, files,
                                force)

@cache_network()
@coerce_props()
@annotate()
def parse(alts=None):
    global files
    name = __name__.split(".")[-1]
    for fnames, alt, fmt in files:
        if alts is not None and alt not in alts:
            continue
        if isinstance(fnames, str):
            fnames = [fnames]
        with ExitStack() as stack:
            fs = [stack.enter_context(open_upstream_file(name, fn, "rb")) for fn in fnames]
            g = parse_graph(fs, fmt, directed=False)
        yield alt, g
